@@ -18,22 +18,33 @@
 
 #include "arch/unix/ArchNetworkBSD.h"
 
-#include "arch/Arch.h"
 #include "arch/unix/ArchMultithreadPosix.h"
 #include "arch/unix/XArchUnix.h"
+#include "arch/Arch.h"
 
 #if HAVE_UNISTD_H
 #    include <unistd.h>
 #endif
-#include <netdb.h>
 #include <netinet/in.h>
+#include <netdb.h>
 #if !defined(TCP_NODELAY)
 #    include <netinet/tcp.h>
 #endif
 #include <arpa/inet.h>
-#include <errno.h>
 #include <fcntl.h>
-#include <cstring>
+#include <errno.h>
+#include <string.h>
+
+#if HAVE_POLL
+#    include <poll.h>
+#else
+#    if HAVE_SYS_SELECT_H
+#        include <sys/select.h>
+#    endif
+#    if HAVE_SYS_TIME_H
+#        include <sys/time.h>
+#    endif
+#endif
 
 #if !HAVE_INET_ATON
 #    include <stdio.h>
@@ -41,8 +52,7 @@
 
 static const int s_family[] = {
     PF_UNSPEC,
-    PF_INET,
-    PF_INET6,
+    PF_INET
 };
 static const int s_type[] = {
     SOCK_DGRAM,
@@ -76,14 +86,13 @@ inet_aton(const char* cp, struct in_addr* inp)
 // ArchNetworkBSD
 //
 
-ArchNetworkBSD::Connectors ArchNetworkBSD::s_connectors;
-
 ArchNetworkBSD::ArchNetworkBSD()
-= default;
+{
+}
 
 ArchNetworkBSD::~ArchNetworkBSD()
 {
-    if (m_mutex) ARCH->closeMutex(m_mutex);
+    ARCH->closeMutex(m_mutex);
 }
 
 void
@@ -110,7 +119,7 @@ ArchNetworkBSD::newSocket(EAddressFamily family, ESocketType type)
     }
 
     // allocate socket object
-    auto* newSocket = new ArchSocketImpl;
+    ArchSocketImpl* newSocket = new ArchSocketImpl;
     newSocket->m_fd            = fd;
     newSocket->m_refCount      = 1;
     return newSocket;
@@ -182,7 +191,7 @@ ArchNetworkBSD::bindSocket(ArchSocket s, ArchNetAddress addr)
     assert(s    != NULL);
     assert(addr != NULL);
 
-    if (bind(s->m_fd, TYPED_ADDR(struct sockaddr, addr), addr->m_len) == -1) {
+    if (bind(s->m_fd, &addr->m_addr, addr->m_len) == -1) {
         throwError(errno);
     }
 }
@@ -205,25 +214,25 @@ ArchNetworkBSD::acceptSocket(ArchSocket s, ArchNetAddress* addr)
 
     // if user passed NULL in addr then use scratch space
     ArchNetAddress dummy;
-    if (addr == nullptr) {
+    if (addr == NULL) {
         addr = &dummy;
     }
 
     // create new socket and address
-    auto* newSocket = new ArchSocketImpl;
+    ArchSocketImpl* newSocket = new ArchSocketImpl;
     *addr                      = new ArchNetAddressImpl;
 
     // accept on socket
-    auto len = ((*addr)->m_len);
-    int fd = accept(s->m_fd, TYPED_ADDR(struct sockaddr, (*addr)), &len);
-    (*addr)->m_len = len;
+    ACCEPT_TYPE_ARG3 len = (ACCEPT_TYPE_ARG3)((*addr)->m_len);
+    int fd = accept(s->m_fd, &(*addr)->m_addr, &len);
+    (*addr)->m_len = (socklen_t)len;
     if (fd == -1) {
         int err = errno;
         delete newSocket;
         delete *addr;
-        *addr = nullptr;
+        *addr = NULL;
         if (err == EAGAIN) {
-            return nullptr;
+            return NULL;
         }
         throwError(err);
     }
@@ -235,7 +244,7 @@ ArchNetworkBSD::acceptSocket(ArchSocket s, ArchNetAddress* addr)
         close(fd);
         delete newSocket;
         delete *addr;
-        *addr = nullptr;
+        *addr = NULL;
         throw;
     }
 
@@ -257,7 +266,7 @@ ArchNetworkBSD::connectSocket(ArchSocket s, ArchNetAddress addr)
     assert(s    != NULL);
     assert(addr != NULL);
 
-    if (connect(s->m_fd, TYPED_ADDR(struct sockaddr, addr), addr->m_len) == -1) {
+    if (connect(s->m_fd, &addr->m_addr, addr->m_len) == -1) {
         if (errno == EISCONN) {
             return true;
         }
@@ -285,11 +294,11 @@ ArchNetworkBSD::pollSocket(PollEntry pe[], int num, double timeout)
     }
 
     // allocate space for translated query
-    auto* pfd = new struct pollfd[1 + num];
+    struct pollfd* pfd = new struct pollfd[1 + num];
 
     // translate query
     for (int i = 0; i < num; ++i) {
-        pfd[i].fd     = (pe[i].m_socket == nullptr) ? -1 : pe[i].m_socket->m_fd;
+        pfd[i].fd     = (pe[i].m_socket == NULL) ? -1 : pe[i].m_socket->m_fd;
         pfd[i].events = 0;
         if ((pe[i].m_events & kPOLLIN) != 0) {
             pfd[i].events |= POLLIN;
@@ -302,7 +311,7 @@ ArchNetworkBSD::pollSocket(PollEntry pe[], int num, double timeout)
 
     // add the unblock pipe
     const int* unblockPipe = getUnblockPipe();
-    if (unblockPipe != nullptr) {
+    if (unblockPipe != NULL) {
         pfd[n].fd     = unblockPipe[0];
         pfd[n].events = POLLIN;
         ++n;
@@ -312,10 +321,10 @@ ArchNetworkBSD::pollSocket(PollEntry pe[], int num, double timeout)
     int t = (timeout < 0.0) ? -1 : static_cast<int>(1000.0 * timeout);
 
     // do the poll
-    n = s_connectors.poll_impl(pfd, n, t);
+    n = poll(pfd, n, t);
 
     // reset the unblock pipe
-    if (n > 0 && unblockPipe != nullptr && (pfd[num].revents & POLLIN) != 0) {
+    if (n > 0 && unblockPipe != NULL && (pfd[num].revents & POLLIN) != 0) {
         // the unblock event was signalled.  flush the pipe.
         char dummy[100];
         int ignore;
@@ -338,7 +347,6 @@ ArchNetworkBSD::pollSocket(PollEntry pe[], int num, double timeout)
         }
         delete[] pfd;
         throwError(errno);
-        return -1;
     }
 
     // translate back
@@ -492,7 +500,7 @@ void
 ArchNetworkBSD::unblockPollSocket(ArchThread thread)
 {
     const int* unblockPipe = getUnblockPipeForThread(thread);
-    if (unblockPipe != nullptr) {
+    if (unblockPipe != NULL) {
         char dummy = 0;
         int ignore;
 
@@ -537,9 +545,9 @@ ArchNetworkBSD::throwErrorOnSocket(ArchSocket s)
 
     // get the error from the socket layer
     int err        = 0;
-    auto size = static_cast<socklen_t>(sizeof(err));
+    socklen_t size = (socklen_t)sizeof(err);
     if (getsockopt(s->m_fd, SOL_SOCKET, SO_ERROR,
-                            reinterpret_cast<optval_t*>(&err), &size) == -1) {
+                            (optval_t*)&err, &size) == -1) {
         err = errno;
     }
 
@@ -576,16 +584,16 @@ ArchNetworkBSD::setNoDelayOnSocket(ArchSocket s, bool noDelay)
 
     // get old state
     int oflag;
-    auto size = static_cast<socklen_t>(sizeof(oflag));
+    socklen_t size = (socklen_t)sizeof(oflag);
     if (getsockopt(s->m_fd, IPPROTO_TCP, TCP_NODELAY,
-                            reinterpret_cast<optval_t*>(&oflag), &size) == -1) {
+                            (optval_t*)&oflag, &size) == -1) {
         throwError(errno);
     }
 
     int flag = noDelay ? 1 : 0;
-    size     = static_cast<socklen_t>(sizeof(flag));
+    size     = (socklen_t)sizeof(flag);
     if (setsockopt(s->m_fd, IPPROTO_TCP, TCP_NODELAY,
-                            reinterpret_cast<optval_t*>(&flag), size) == -1) {
+                            (optval_t*)&flag, size) == -1) {
         throwError(errno);
     }
 
@@ -599,16 +607,16 @@ ArchNetworkBSD::setReuseAddrOnSocket(ArchSocket s, bool reuse)
 
     // get old state
     int oflag;
-    auto size = static_cast<socklen_t>(sizeof(oflag));
+    socklen_t size = (socklen_t)sizeof(oflag);
     if (getsockopt(s->m_fd, SOL_SOCKET, SO_REUSEADDR,
-                            reinterpret_cast<optval_t*>(&oflag), &size) == -1) {
+                            (optval_t*)&oflag, &size) == -1) {
         throwError(errno);
     }
 
     int flag = reuse ? 1 : 0;
-    size     = static_cast<socklen_t>(sizeof(flag));
+    size     = (socklen_t)sizeof(flag);
     if (setsockopt(s->m_fd, SOL_SOCKET, SO_REUSEADDR,
-                            reinterpret_cast<optval_t*>(&flag), size) == -1) {
+                            (optval_t*)&flag, size) == -1) {
         throwError(errno);
     }
 
@@ -632,27 +640,20 @@ ArchNetAddress
 ArchNetworkBSD::newAnyAddr(EAddressFamily family)
 {
     // allocate address
-    auto* addr = new ArchNetAddressImpl;
+    ArchNetAddressImpl* addr = new ArchNetAddressImpl;
 
     // fill it in
     switch (family) {
     case kINET: {
-        auto* ipAddr = TYPED_ADDR(struct sockaddr_in, addr);
+        struct sockaddr_in* ipAddr =
+                reinterpret_cast<struct sockaddr_in*>(&addr->m_addr);
         ipAddr->sin_family         = AF_INET;
         ipAddr->sin_port           = 0;
         ipAddr->sin_addr.s_addr    = INADDR_ANY;
-        addr->m_len                = static_cast<socklen_t>(sizeof(struct sockaddr_in));
+        addr->m_len                = (socklen_t)sizeof(struct sockaddr_in);
         break;
     }
 
-    case kINET6: {
-        struct sockaddr_in6* ipAddr = TYPED_ADDR(struct sockaddr_in6, addr);
-        ipAddr->sin6_family         = AF_INET6;
-        ipAddr->sin6_port           = 0;
-        memcpy(&ipAddr->sin6_addr, &in6addr_any, sizeof(in6addr_any));
-        addr->m_len                = (socklen_t)sizeof(struct sockaddr_in6);
-        break;
-    }
     default:
         delete addr;
         assert(0 && "invalid family");
@@ -670,55 +671,55 @@ ArchNetworkBSD::copyAddr(ArchNetAddress addr)
     return new ArchNetAddressImpl(*addr);
 }
 
-std::vector<ArchNetAddress>
+ArchNetAddress
 ArchNetworkBSD::nameToAddr(const std::string& name)
 {
     // allocate address
-    std::vector<ArchNetAddressImpl*> addresses;
+    ArchNetAddressImpl* addr = new ArchNetAddressImpl;
 
-    char ipstr[INET6_ADDRSTRLEN];
-    struct addrinfo hints;
-    struct addrinfo *pResult;
-    struct in6_addr serveraddr;
-    int ret;
-
-    memset(&hints, 0, sizeof(hints));
-    hints.ai_flags    = AI_NUMERICSERV;
-    hints.ai_family   = AF_UNSPEC;
-    hints.ai_socktype = SOCK_STREAM;
-
-    if (inet_pton(AF_INET, name.c_str(), &serveraddr) == 1) {
-        hints.ai_family = AF_INET;
-        hints.ai_flags |= AI_NUMERICHOST;
-    }
-    else if (inet_pton(AF_INET6, name.c_str(), &serveraddr) == 1) {
-        hints.ai_family = AF_INET6;
-        hints.ai_flags |= AI_NUMERICHOST;
+    // try to convert assuming an IPv4 dot notation address
+    struct sockaddr_in inaddr;
+    memset(&inaddr, 0, sizeof(inaddr));
+    if (inet_aton(name.c_str(), &inaddr.sin_addr) != 0) {
+        // it's a dot notation address
+        addr->m_len       = (socklen_t)sizeof(struct sockaddr_in);
+        inaddr.sin_family = AF_INET;
+        inaddr.sin_port   = 0;
+        memcpy(&addr->m_addr, &inaddr, addr->m_len);
     }
 
-    // done with static buffer
-    ARCH->lockMutex(m_mutex);
-    ret = getaddrinfo(name.c_str(), nullptr, &hints, &pResult);
-    if (ret != 0) {
-        ARCH->unlockMutex(m_mutex);
-        throwNameError(ret);
-    }
-
-    for(; pResult != nullptr; pResult = pResult->ai_next ) {
-        addresses.push_back(new ArchNetAddressImpl);
-        if (pResult->ai_family == AF_INET) {
-            addresses.back()->m_len = (socklen_t)sizeof(struct sockaddr_in);
-        } else {
-            addresses.back()->m_len = (socklen_t)sizeof(struct sockaddr_in6);
+    else {
+        // mutexed address lookup (ugh)
+        ARCH->lockMutex(m_mutex);
+        struct hostent* info = gethostbyname(name.c_str());
+        if (info == NULL) {
+            ARCH->unlockMutex(m_mutex);
+            delete addr;
+            throwNameError(h_errno);
         }
 
-        memcpy(&addresses.back()->m_addr, pResult->ai_addr, addresses.back()->m_len);
+        // copy over address (only IPv4 currently supported)
+        if (info->h_addrtype == AF_INET) {
+            addr->m_len       = (socklen_t)sizeof(struct sockaddr_in);
+            inaddr.sin_family = info->h_addrtype;
+            inaddr.sin_port   = 0;
+            memcpy(&inaddr.sin_addr, info->h_addr_list[0],
+                                sizeof(inaddr.sin_addr));
+            memcpy(&addr->m_addr, &inaddr, addr->m_len);
+        }
+        else {
+            ARCH->unlockMutex(m_mutex);
+            delete addr;
+            throw XArchNetworkNameUnsupported(
+                    "The requested name is valid but "
+                    "does not have a supported address family");
+        }
+
+        // done with static buffer
+        ARCH->unlockMutex(m_mutex);
     }
 
-    freeaddrinfo(pResult);
-    ARCH->unlockMutex(m_mutex);
-
-    return addresses;
+    return addr;
 }
 
 void
@@ -736,16 +737,15 @@ ArchNetworkBSD::addrToName(ArchNetAddress addr)
 
     // mutexed name lookup (ugh)
     ARCH->lockMutex(m_mutex);
-    char host[1024];
-    char service[20];
-    int ret = getnameinfo(TYPED_ADDR(struct sockaddr, addr), addr->m_len, host, sizeof(host), service, sizeof(service), 0);
-    if (ret != 0) {
-         ARCH->unlockMutex(m_mutex);
-         throwNameError(ret);
+    struct hostent* info = gethostbyaddr(&addr->m_addr,
+                            addr->m_len, addr->m_addr.sa_family);
+    if (info == NULL) {
+        ARCH->unlockMutex(m_mutex);
+        throwNameError(h_errno);
     }
 
     // save (primary) name
-    std::string name = host;
+    std::string name = info->h_name;
 
     // done with static buffer
     ARCH->unlockMutex(m_mutex);
@@ -760,22 +760,14 @@ ArchNetworkBSD::addrToString(ArchNetAddress addr)
 
     switch (getAddrFamily(addr)) {
     case kINET: {
-        auto* ipAddr = TYPED_ADDR(struct sockaddr_in, addr);
+        struct sockaddr_in* ipAddr =
+            reinterpret_cast<struct sockaddr_in*>(&addr->m_addr);
         ARCH->lockMutex(m_mutex);
         std::string s = inet_ntoa(ipAddr->sin_addr);
         ARCH->unlockMutex(m_mutex);
         return s;
     }
 
-    case kINET6: {
-        char strAddr[INET6_ADDRSTRLEN];
-        struct sockaddr_in6* ipAddr = TYPED_ADDR(struct sockaddr_in6, addr);
-        ARCH->lockMutex(m_mutex);
-        inet_ntop(AF_INET6, &ipAddr->sin6_addr, strAddr, INET6_ADDRSTRLEN);
-        ARCH->unlockMutex(m_mutex);
-        return strAddr;
-    }
-
     default:
         assert(0 && "unknown address family");
         return "";
@@ -787,11 +779,9 @@ ArchNetworkBSD::getAddrFamily(ArchNetAddress addr)
 {
     assert(addr != NULL);
 
-    switch (addr->m_addr.ss_family) {
+    switch (addr->m_addr.sa_family) {
     case AF_INET:
         return kINET;
-    case AF_INET6:
-        return kINET6;
 
     default:
         return kUNKNOWN;
@@ -805,17 +795,12 @@ ArchNetworkBSD::setAddrPort(ArchNetAddress addr, int port)
 
     switch (getAddrFamily(addr)) {
     case kINET: {
-        auto* ipAddr = TYPED_ADDR(struct sockaddr_in, addr);
+        struct sockaddr_in* ipAddr =
+            reinterpret_cast<struct sockaddr_in*>(&addr->m_addr);
         ipAddr->sin_port = htons(port);
         break;
     }
 
-    case kINET6: {
-        struct sockaddr_in6* ipAddr = TYPED_ADDR(struct sockaddr_in6, addr);
-        ipAddr->sin6_port = htons(port);
-        break;
-    }
-
     default:
         assert(0 && "unknown address family");
         break;
@@ -829,15 +814,11 @@ ArchNetworkBSD::getAddrPort(ArchNetAddress addr)
 
     switch (getAddrFamily(addr)) {
     case kINET: {
-        auto* ipAddr = TYPED_ADDR(struct sockaddr_in, addr);
+        struct sockaddr_in* ipAddr =
+            reinterpret_cast<struct sockaddr_in*>(&addr->m_addr);
         return ntohs(ipAddr->sin_port);
     }
 
-    case kINET6: {
-        struct sockaddr_in6* ipAddr = TYPED_ADDR(struct sockaddr_in6, addr);
-        return ntohs(ipAddr->sin6_port);
-    }
-
     default:
         assert(0 && "unknown address family");
         return 0;
@@ -851,15 +832,10 @@ ArchNetworkBSD::isAnyAddr(ArchNetAddress addr)
 
     switch (getAddrFamily(addr)) {
     case kINET: {
-        auto* ipAddr = TYPED_ADDR(struct sockaddr_in, addr);
+        struct sockaddr_in* ipAddr =
+                reinterpret_cast<struct sockaddr_in*>(&addr->m_addr);
         return (ipAddr->sin_addr.s_addr == INADDR_ANY &&
-                addr->m_len == static_cast<socklen_t>(sizeof(struct sockaddr_in)));
-    }
-
-    case kINET6: {
-        struct sockaddr_in6* ipAddr = TYPED_ADDR(struct sockaddr_in6, addr);
-        return (addr->m_len == (socklen_t)sizeof(struct sockaddr_in6) &&
-            memcmp(static_cast<const void*>(&ipAddr->sin6_addr), static_cast<const void*>(&in6addr_any), sizeof(in6_addr)) == 0);
+                addr->m_len == (socklen_t)sizeof(struct sockaddr_in));
     }
 
     default:
@@ -889,8 +865,8 @@ const int*
 ArchNetworkBSD::getUnblockPipeForThread(ArchThread thread)
 {
     ArchMultithreadPosix* mt = ArchMultithreadPosix::getInstance();
-    auto* unblockPipe          = static_cast<int*>(mt->getNetworkDataForThread(thread));
-    if (unblockPipe == nullptr) {
+    int* unblockPipe          = (int*)mt->getNetworkDataForThread(thread);
+    if (unblockPipe == NULL) {
         unblockPipe = new int[2];
         if (pipe(unblockPipe) != -1) {
             try {
@@ -899,12 +875,12 @@ ArchNetworkBSD::getUnblockPipeForThread(ArchThread thread)
             }
             catch (...) {
                 delete[] unblockPipe;
-                unblockPipe = nullptr;
+                unblockPipe = NULL;
             }
         }
         else {
             delete[] unblockPipe;
-            unblockPipe = nullptr;
+            unblockPipe = NULL;
         }
     }
     return unblockPipe;
