@@ -19,15 +19,15 @@
 #include "client/Client.h"
 
 #include "client/ServerProxy.h"
-#include "synergy/Screen.h"
-#include "synergy/FileChunk.h"
-#include "synergy/DropHelper.h"
-#include "synergy/PacketStreamFilter.h"
-#include "synergy/ProtocolUtil.h"
-#include "synergy/protocol_types.h"
-#include "synergy/XSynergy.h"
-#include "synergy/StreamChunker.h"
-#include "synergy/IPlatformScreen.h"
+#include "core/Screen.h"
+#include "core/FileChunk.h"
+#include "core/DropHelper.h"
+#include "core/PacketStreamFilter.h"
+#include "core/ProtocolUtil.h"
+#include "core/protocol_types.h"
+#include "core/XSynergy.h"
+#include "core/StreamChunker.h"
+#include "core/IPlatformScreen.h"
 #include "mt/Thread.h"
 #include "net/TCPSocket.h"
 #include "net/IDataSocket.h"
@@ -44,8 +44,6 @@
 #include <cstdlib>
 #include <sstream>
 #include <fstream>
-#include <algorithm>
-#include <climits>
 
 //
 // Client
@@ -56,7 +54,7 @@ Client::Client(
         const String& name, const NetworkAddress& address,
         ISocketFactory* socketFactory,
         synergy::Screen* screen,
-        lib::synergy::ClientArgs const& args) :
+        ClientArgs const& args) :
     m_mock(false),
     m_name(name),
     m_serverAddress(address),
@@ -75,8 +73,7 @@ Client::Client(
     m_socket(NULL),
     m_useSecureNetwork(args.m_enableCrypto),
     m_args(args),
-    m_enableClipboard(true),
-	m_maximumClipboardSize(INT_MAX)
+    m_enableClipboard(true)
 {
     assert(m_socketFactory != NULL);
     assert(m_screen        != NULL);
@@ -122,7 +119,7 @@ Client::~Client()
 }
 
 void
-Client::connect(size_t addressIndex)
+Client::connect()
 {
     if (m_stream != NULL) {
         return;
@@ -138,10 +135,10 @@ Client::connect(size_t addressIndex)
         // has changed (which can happen frequently if this is a laptop
         // being shuttled between various networks).  patch by Brent
         // Priddy.
-        m_resolvedAddressesCount = m_serverAddress.resolve(addressIndex);
+        m_serverAddress.resolve();
         
         // m_serverAddress will be null if the hostname address is not reolved
-        if (m_serverAddress.getAddress() != nullptr) {
+        if (m_serverAddress.getAddress() != NULL) {
           // to help users troubleshoot, show server host name (issue: 60)
           LOG((CLOG_NOTE "connecting to '%s': %s:%i", 
           m_serverAddress.getHostname().c_str(),
@@ -150,7 +147,7 @@ Client::connect(size_t addressIndex)
         }
 
         // create the socket
-        IDataSocket* socket = m_socketFactory->create(m_useSecureNetwork, ARCH->getAddrFamily(m_serverAddress.getAddress()));
+        IDataSocket* socket = m_socketFactory->create(m_useSecureNetwork);
         m_socket = dynamic_cast<TCPSocket*>(socket);
 
         // filter socket messages, including a packetizing filter
@@ -176,9 +173,12 @@ Client::connect(size_t addressIndex)
 void
 Client::disconnect(const char* msg)
 {
-    cleanup();
-
-    if (msg) {
+    m_connectOnResume = false;
+    cleanupTimer();
+    cleanupScreen();
+    cleanupConnecting();
+    cleanupConnection();
+    if (msg != NULL) {
         sendConnectionFailedEvent(msg);
     }
     else {
@@ -186,19 +186,6 @@ Client::disconnect(const char* msg)
     }
 }
 
-void
-Client::refuseConnection(const char* msg)
-{
-    cleanup();
-
-    if (msg) {
-        auto info = new FailInfo(msg);
-        info->m_retry = true;
-        Event event(m_events->forClient().connectionRefused(), getEventTarget(), info, Event::kDontFreeData);
-        m_events->addEvent(event);
-    }
-}
-
 void
 Client::handshakeComplete()
 {
@@ -372,24 +359,13 @@ Client::setOptions(const OptionsList& options)
         const OptionID id       = *index;
         if (id == kOptionClipboardSharing) {
             index++;
-            if (index != options.end()) {
-				if (!*index) {
-					LOG((CLOG_NOTE "clipboard sharing disabled by server"));
-                }
-                m_enableClipboard = *index;
+            if (*index == static_cast<OptionValue>(false)) {
+                LOG((CLOG_NOTE "clipboard sharing is disabled"));
             }
-        } else if (id == kOptionClipboardSharingSize) {
-            index++;
-            if (index != options.end()) {
-				m_maximumClipboardSize = *index;
-            }
-        }
-    }
+            m_enableClipboard = *index;
 
-    if (m_enableClipboard && !m_maximumClipboardSize) {
-        m_enableClipboard = false;
-        LOG((CLOG_NOTE "clipboard sharing is disabled because the server "
-                       "set the maximum clipboard size to 0"));
+            break;
+        }
     }
 
     m_screen->setOptions(options);
@@ -421,17 +397,12 @@ Client::sendClipboard(ClipboardID id)
     // check time
     if (m_timeClipboard[id] == 0 ||
         clipboard.getTime() != m_timeClipboard[id]) {
+        // save new time
+        m_timeClipboard[id] = clipboard.getTime();
+
         // marshall the data
-		String data = clipboard.marshall();
-		if (data.size() >= m_maximumClipboardSize * 1024) {
-			LOG((CLOG_NOTE "Skipping clipboard transfer because the clipboard"
-				" contents exceeds the %i MB size limit set by the server",
-				m_maximumClipboardSize / 1024));
-			return;
-		}
+        String data = clipboard.marshall();
 
-		// save new time
-		m_timeClipboard[id] = clipboard.getTime();
         // save and send data if different or not yet sent
         if (!m_sentClipboard[id] || data != m_dataClipboard[id]) {
             m_sentClipboard[id] = true;
@@ -544,22 +515,12 @@ Client::setupTimer()
 {
     assert(m_timer == NULL);
 
-    m_timer = m_events->newOneShotTimer(2.0, NULL);
+    m_timer = m_events->newOneShotTimer(15.0, NULL);
     m_events->adoptHandler(Event::kTimer, m_timer,
                             new TMethodEventJob<Client>(this,
                                 &Client::handleConnectTimeout));
 }
 
-void
-Client::cleanup()
-{
-    m_connectOnResume = false;
-    cleanupTimer();
-    cleanupScreen();
-    cleanupConnecting();
-    cleanupConnection();
-}
-
 void
 Client::cleanupConnecting()
 {
@@ -695,7 +656,7 @@ Client::handleShapeChanged(const Event&, void*)
 void
 Client::handleClipboardGrabbed(const Event& event, void*)
 {
-    if (!m_enableClipboard || (m_maximumClipboardSize == 0)) {
+    if (!m_enableClipboard) {
         return;
     }
 
@@ -730,14 +691,7 @@ Client::handleHello(const Event&, void*)
 
     // check versions
     LOG((CLOG_DEBUG1 "got hello version %d.%d", major, minor));
-    SInt16 helloBackMajor = kProtocolMajorVersion;
-    SInt16 helloBackMinor = kProtocolMinorVersion;
-    if (major == kProtocolMajorVersion && minor == 6 && kProtocolMinorVersion == 7) {
-        //because 1.6 and 1.7 is comptable - downgrading protocol for server
-        LOG((CLOG_NOTE "Downgrading protocol version for server"));
-        helloBackMinor = minor;
-    }
-    else if (major < kProtocolMajorVersion ||
+    if (major < kProtocolMajorVersion ||
         (major == kProtocolMajorVersion && minor < kProtocolMinorVersion)) {
         sendConnectionFailedEvent(XIncompatibleClient(major, minor).what());
         cleanupTimer();
@@ -746,10 +700,10 @@ Client::handleHello(const Event&, void*)
     }
 
     // say hello back
-    LOG((CLOG_DEBUG1 "say hello version %d.%d", helloBackMajor, helloBackMinor));
+    LOG((CLOG_DEBUG1 "say hello version %d.%d", kProtocolMajorVersion, kProtocolMinorVersion));
     ProtocolUtil::writef(m_stream, kMsgHelloBack,
-                            helloBackMajor,
-                            helloBackMinor, & m_name);
+                            kProtocolMajorVersion,
+                            kProtocolMinorVersion, &m_name);
 
     // now connected but waiting to complete handshake
     setupScreen();
