@@ -18,12 +18,12 @@
 
 #pragma once
 
-#include "synergy/IClient.h"
+#include "core/IClient.h"
 
-#include "synergy/Clipboard.h"
-#include "synergy/DragInformation.h"
-#include "synergy/INode.h"
-#include "synergy/ClientArgs.h"
+#include "core/Clipboard.h"
+#include "core/DragInformation.h"
+#include "core/INode.h"
+#include "core/ClientArgs.h"
 #include "net/NetworkAddress.h"
 #include "base/EventTypes.h"
 #include "mt/CondVar.h"
@@ -59,13 +59,9 @@ public:
     */
     Client(IEventQueue* events, const String& name,
            const NetworkAddress& address, ISocketFactory* socketFactory,
-           synergy::Screen* screen, lib::synergy::ClientArgs const& args);
-    Client(Client const &) =delete;
-    Client(Client &&) =delete;
-    ~Client();
+           synergy::Screen* screen, ClientArgs const& args);
 
-    Client& operator=(Client const &) =delete;
-    Client& operator=(Client &&) =delete;
+    ~Client();
 
     //! @name manipulators
     //@{
@@ -75,7 +71,7 @@ public:
     Starts an attempt to connect to the server.  This is ignored if
     the client is trying to connect or is already connected.
     */
-    void                connect(size_t addressIndex = 0);
+    void                connect();
 
     //! Disconnect
     /*!
@@ -83,13 +79,6 @@ public:
     */
     void                disconnect(const char* msg);
 
-    //! Refuse connection
-    /*!
-    Disconnects from the server with an optional error message.
-    Unlike disconnect this function doesn't try to use other ip addresses
-    */
-    void                refuseConnection(const char* msg);
-
     //! Notify of handshake complete
     /*!
     Notifies the client that the connection handshake has completed.
@@ -130,7 +119,7 @@ public:
     */
     NetworkAddress        getServerAddress() const;
     
-    //! Return true if received file size is valid
+    //! Return true if recieved file size is valid
     bool                isReceivedFileSizeValid();
 
     //! Return expected file size
@@ -142,9 +131,6 @@ public:
     //! Return drag file list
     DragFileList        getDragFileList() { return m_dragFileList; }
 
-    //! Return last resolved adresses count
-    size_t              getLastResolvedAddressesCount() const { return m_resolvedAddressesCount; }
-
     //@}
 
     // IScreen overrides
@@ -187,7 +173,6 @@ private:
     void                setupConnection();
     void                setupScreen();
     void                setupTimer();
-    void                cleanup();
     void                cleanupConnecting();
     void                cleanupConnection();
     void                cleanupScreen();
@@ -213,11 +198,11 @@ public:
     bool                m_mock;
 
 private:
-    String              m_name;
-    NetworkAddress      m_serverAddress;
-    ISocketFactory*     m_socketFactory;
+    String                m_name;
+    NetworkAddress        m_serverAddress;
+    ISocketFactory*        m_socketFactory;
     synergy::Screen*    m_screen;
-    synergy::IStream*   m_stream;
+    synergy::IStream*    m_stream;
     EventQueueTimer*    m_timer;
     ServerProxy*        m_server;
     bool                m_ready;
@@ -227,18 +212,16 @@ private:
     bool                m_ownClipboard[kClipboardEnd];
     bool                m_sentClipboard[kClipboardEnd];
     IClipboard::Time    m_timeClipboard[kClipboardEnd];
-    String              m_dataClipboard[kClipboardEnd];
+    String                m_dataClipboard[kClipboardEnd];
     IEventQueue*        m_events;
-    std::size_t         m_expectedFileSize;
-    String              m_receivedFileData;
+    std::size_t            m_expectedFileSize;
+    String                m_receivedFileData;
     DragFileList        m_dragFileList;
-    String              m_dragFileExt;
-    Thread*             m_sendFileThread;
-    Thread*             m_writeToDropDirThread;
-    TCPSocket*          m_socket;
+    String                m_dragFileExt;
+    Thread*                m_sendFileThread;
+    Thread*                m_writeToDropDirThread;
+    TCPSocket*            m_socket;
     bool                m_useSecureNetwork;
+    ClientArgs            m_args;
     bool                m_enableClipboard;
-    size_t              m_maximumClipboardSize;
-    lib::synergy::ClientArgs          m_args;
-    size_t              m_resolvedAddressesCount = 0;
 };
