@@ -22,8 +22,6 @@
 #include "net/SocketMultiplexer.h"
 #include "net/TSocketMultiplexerMethodJob.h"
 #include "arch/XArch.h"
-#include "synergy/ArgParser.h"
-#include "synergy/ArgsBase.h"
 
 static const char s_certificateDir[] = { "SSL" };
 static const char s_certificateFilename[] = { "Synergy.pem" };
@@ -34,12 +32,20 @@ static const char s_certificateFilename[] = { "Synergy.pem" };
 
 SecureListenSocket::SecureListenSocket(
         IEventQueue* events,
-        SocketMultiplexer* socketMultiplexer,
-        IArchNetwork::EAddressFamily family) :
-    TCPListenSocket(events, socketMultiplexer, family)
+        SocketMultiplexer* socketMultiplexer) :
+    TCPListenSocket(events, socketMultiplexer)
 {
 }
 
+SecureListenSocket::~SecureListenSocket()
+{
+    SecureSocketSet::iterator it;
+    for (it = m_secureSocketSet.begin(); it != m_secureSocketSet.end(); it++) {
+        delete *it;
+    }
+    m_secureSocketSet.clear();
+}
+
 IDataSocket*
 SecureListenSocket::accept()
 {
@@ -55,16 +61,10 @@ SecureListenSocket::accept()
             setListeningJob();
         }
 
-        //default location of the TLS cert file in users dir
         String certificateFilename = synergy::string::sprintf("%s/%s/%s",
-                                                              ARCH->getProfileDirectory().c_str(),
-                                                              s_certificateDir,
-                                                              s_certificateFilename);
-
-        //if the tls cert option is set use that for the certificate file
-        if (!ArgParser::argsBase().m_tlsCertFile.empty()) {
-            certificateFilename = ArgParser::argsBase().m_tlsCertFile;
-        }
+                                        ARCH->getProfileDirectory().c_str(),
+                                        s_certificateDir,
+                                        s_certificateFilename);
 
         bool loaded = socket->loadCertificates(certificateFilename);
         if (!loaded) {
@@ -74,6 +74,8 @@ SecureListenSocket::accept()
 
         socket->secureAccept();
 
+        m_secureSocketSet.insert(socket);
+
         return dynamic_cast<IDataSocket*>(socket);
     }
     catch (XArchNetwork&) {
