@@ -27,10 +27,15 @@ class IDataSocket;
 class SecureListenSocket : public TCPListenSocket{
 public:
     SecureListenSocket(IEventQueue* events,
-        SocketMultiplexer* socketMultiplexer, IArchNetwork::EAddressFamily family);
-
+        SocketMultiplexer* socketMultiplexer);
+    ~SecureListenSocket();
 
     // IListenSocket overrides
     virtual IDataSocket*
                         accept();
+
+private:
+    typedef std::set<IDataSocket*> SecureSocketSet;
+
+    SecureSocketSet        m_secureSocketSet;
 };
