@@ -32,14 +32,9 @@ A listen socket using TCP.
 */
 class TCPListenSocket : public IListenSocket {
 public:
-    TCPListenSocket(IEventQueue* events, SocketMultiplexer* socketMultiplexer, IArchNetwork::EAddressFamily family);
-    TCPListenSocket(TCPListenSocket const &) =delete;
-    TCPListenSocket(TCPListenSocket &&) =delete;
+    TCPListenSocket(IEventQueue* events, SocketMultiplexer* socketMultiplexer);
     virtual ~TCPListenSocket();
 
-    TCPListenSocket& operator=(TCPListenSocket const &) =delete;
-    TCPListenSocket& operator=(TCPListenSocket &&) =delete;
-
     // ISocket overrides
     virtual void        bind(const NetworkAddress&);
     virtual void        close();
