@@ -37,7 +37,7 @@
 // TCPSocket
 //
 
-TCPSocket::TCPSocket(IEventQueue* events, SocketMultiplexer* socketMultiplexer, IArchNetwork::EAddressFamily family) :
+TCPSocket::TCPSocket(IEventQueue* events, SocketMultiplexer* socketMultiplexer) :
     IDataSocket(events),
     m_events(events),
     m_mutex(),
@@ -45,14 +45,12 @@ TCPSocket::TCPSocket(IEventQueue* events, SocketMultiplexer* socketMultiplexer,
     m_socketMultiplexer(socketMultiplexer)
 {
     try {
-        m_socket = ARCH->newSocket(family, IArchNetwork::kSTREAM);
+        m_socket = ARCH->newSocket(IArchNetwork::kINET, IArchNetwork::kSTREAM);
     }
-    catch (const XArchNetwork& e) {
+    catch (XArchNetwork& e) {
         throw XSocketCreate(e.what());
     }
 
-    LOG((CLOG_DEBUG "Opening new socket: %08X", m_socket));
-
     init();
 }
 
@@ -64,9 +62,7 @@ TCPSocket::TCPSocket(IEventQueue* events, SocketMultiplexer* socketMultiplexer,
     m_flushed(&m_mutex, true),
     m_socketMultiplexer(socketMultiplexer)
 {
-    assert(m_socket != nullptr);
-
-    LOG((CLOG_DEBUG "Opening new socket: %08X", m_socket));
+    assert(m_socket != NULL);
 
     // socket starts in connected state
     init();
@@ -77,11 +73,10 @@ TCPSocket::TCPSocket(IEventQueue* events, SocketMultiplexer* socketMultiplexer,
 TCPSocket::~TCPSocket()
 {
     try {
-        // warning virtual function in destructor is very danger practice
         close();
     }
     catch (...) {
-        LOG((CLOG_DEBUG "error while TCP socket destruction"));
+        // ignore
     }
 }
 
@@ -91,10 +86,10 @@ TCPSocket::bind(const NetworkAddress& addr)
     try {
         ARCH->bindSocket(m_socket, addr.getAddress());
     }
-    catch (const XArchNetworkAddressInUse& e) {
+    catch (XArchNetworkAddressInUse& e) {
         throw XSocketAddressInUse(e.what());
     }
-    catch (const XArchNetwork& e) {
+    catch (XArchNetwork& e) {
         throw XSocketBind(e.what());
     }
 }
@@ -102,10 +97,8 @@ TCPSocket::bind(const NetworkAddress& addr)
 void
 TCPSocket::close()
 {
-    LOG((CLOG_DEBUG "Closing socket: %08X", m_socket));
-
     // remove ourself from the multiplexer
-    setJob(nullptr);
+    setJob(NULL);
 
     Lock lock(&m_mutex);
 
@@ -116,13 +109,13 @@ TCPSocket::close()
     onDisconnected();
 
     // close the socket
-    if (m_socket != nullptr) {
+    if (m_socket != NULL) {
         ArchSocket socket = m_socket;
-        m_socket = nullptr;
+        m_socket = NULL;
         try {
             ARCH->closeSocket(socket);
         }
-        catch (const XArchNetwork& e) {
+        catch (XArchNetwork& e) {
             // ignore, there's not much we can do
             LOG((CLOG_WARN "error closing socket: %s", e.what()));
         }
@@ -144,7 +137,7 @@ TCPSocket::read(void* buffer, UInt32 n)
     if (n > size) {
         n = size;
     }
-    if (buffer != nullptr && n != 0) {
+    if (buffer != NULL && n != 0) {
         memcpy(buffer, m_inputBuffer.peek(n), n);
     }
     m_inputBuffer.pop(n);
@@ -210,9 +203,8 @@ TCPSocket::shutdownInput()
         try {
             ARCH->closeSocketForRead(m_socket);
         }
-        catch (const XArchNetwork& e) {
-            // ignore, there's not much we can do
-            LOG((CLOG_WARN "error closing socket: %s", e.what()));
+        catch (XArchNetwork&) {
+            // ignore
         }
 
         // shutdown buffer for reading
@@ -238,9 +230,8 @@ TCPSocket::shutdownOutput()
         try {
             ARCH->closeSocketForWrite(m_socket);
         }
-        catch (const XArchNetwork& e) {
-            // ignore, there's not much we can do
-            LOG((CLOG_WARN "error closing socket: %s", e.what()));
+        catch (XArchNetwork&) {
+            // ignore
         }
 
         // shutdown buffer for writing
@@ -284,7 +275,7 @@ TCPSocket::connect(const NetworkAddress& addr)
         Lock lock(&m_mutex);
 
         // fail on attempts to reconnect
-        if (m_socket == nullptr || m_connected) {
+        if (m_socket == NULL || m_connected) {
             sendConnectionFailedEvent("busy");
             return;
         }
@@ -299,7 +290,7 @@ TCPSocket::connect(const NetworkAddress& addr)
                 m_writable = true;
             }
         }
-        catch (const XArchNetwork& e) {
+        catch (XArchNetwork& e) {
             throw XSocketConnect(e.what());
         }
     }
@@ -320,14 +311,13 @@ TCPSocket::init()
         // mouse motion messages are much less useful if they're delayed.
         ARCH->setNoDelayOnSocket(m_socket, true);
     }
-    catch (const XArchNetwork& e) {
+    catch (XArchNetwork& e) {
         try {
             ARCH->closeSocket(m_socket);
-            m_socket = nullptr;
+            m_socket = NULL;
         }
-        catch (const XArchNetwork& e) {
-            // ignore, there's not much we can do
-            LOG((CLOG_WARN "error closing socket: %s", e.what()));
+        catch (XArchNetwork&) {
+            // ignore
         }
         throw XSocketCreate(e.what());
     }
@@ -347,7 +337,7 @@ TCPSocket::doRead()
         
         // slurp up as much as possible
         do {
-            m_inputBuffer.write(buffer, static_cast<UInt32>(bytesRead));
+            m_inputBuffer.write(buffer, bytesRead);
 
             bytesRead = ARCH->readSocket(m_socket, buffer, sizeof(buffer));
         } while (bytesRead > 0);
@@ -396,7 +386,7 @@ void
 TCPSocket::setJob(ISocketMultiplexerJob* job)
 {
     // multiplexer will delete the old job
-    if (job == nullptr) {
+    if (job == NULL) {
         m_socketMultiplexer->removeSocket(this);
     }
     else {
@@ -409,13 +399,13 @@ TCPSocket::newJob()
 {
     // note -- must have m_mutex locked on entry
 
-    if (m_socket == nullptr) {
-        return nullptr;
+    if (m_socket == NULL) {
+        return NULL;
     }
     else if (!m_connected) {
         assert(!m_readable);
         if (!(m_readable || m_writable)) {
-            return nullptr;
+            return NULL;
         }
         return new TSocketMultiplexerMethodJob<TCPSocket>(
                                 this, &TCPSocket::serviceConnecting,
@@ -423,7 +413,7 @@ TCPSocket::newJob()
     }
     else {
         if (!(m_readable || (m_writable && (m_outputBuffer.getSize() > 0)))) {
-            return nullptr;
+            return NULL;
         }
         return new TSocketMultiplexerMethodJob<TCPSocket>(
                                 this, &TCPSocket::serviceConnected,
@@ -443,7 +433,7 @@ TCPSocket::sendConnectionFailedEvent(const char* msg)
 void
 TCPSocket::sendEvent(Event::Type type)
 {
-    m_events->addEvent(Event(type, getEventTarget(), nullptr));
+    m_events->addEvent(Event(type, getEventTarget(), NULL));
 }
 
 void
@@ -520,7 +510,7 @@ TCPSocket::serviceConnecting(ISocketMultiplexerJob* job,
             // connection may have failed or succeeded
             ARCH->throwErrorOnSocket(m_socket);
         }
-        catch (const XArchNetwork& e) {
+        catch (XArchNetwork& e) {
             sendConnectionFailedEvent(e.what());
             onDisconnected();
             return newJob();
@@ -596,9 +586,5 @@ TCPSocket::serviceConnected(ISocketMultiplexerJob* job,
         }
     }
 
-    if (result == kBreak) {
-        return nullptr;
-    }
-
-    return result == kNew ? newJob() : job;
+    return result == kBreak ? NULL : result == kNew ? newJob() : job;
 }
