@@ -19,7 +19,6 @@
 #pragma once
 
 #include "net/ISocketFactory.h"
-#include "arch/IArchNetwork.h"
 
 class IEventQueue;
 class SocketMultiplexer;
@@ -32,9 +31,9 @@ public:
 
     // ISocketFactory overrides
     virtual IDataSocket*
-                        create(bool secure, IArchNetwork::EAddressFamily family = IArchNetwork::kINET) const;
+                        create(bool secure) const;
     virtual IListenSocket*
-                        createListen(bool secure, IArchNetwork::EAddressFamily family = IArchNetwork::kINET) const;
+                        createListen(bool secure) const;
 
 private:
     IEventQueue*        m_events;
