@@ -22,8 +22,8 @@
 #include "ipc/IpcServer.h"
 #include "ipc/IpcMessage.h"
 #include "ipc/Ipc.h"
-#include "synergy/App.h"
-#include "synergy/ArgsBase.h"
+#include "core/App.h"
+#include "core/ArgsBase.h"
 #include "mt/Thread.h"
 #include "arch/win32/ArchDaemonWindows.h"
 #include "arch/win32/XArchWindows.h"
