@@ -18,8 +18,8 @@
 
 #include "platform/OSXScreen.h"
 
-#include "base/EventQueue.h"
 #include "client/Client.h"
+#include "platform/OSXIOHID.h"
 #include "platform/OSXClipboard.h"
 #include "platform/OSXEventQueueBuffer.h"
 #include "platform/OSXKeyState.h"
@@ -27,25 +27,26 @@
 #include "platform/OSXDragSimulator.h"
 #include "platform/OSXMediaKeySupport.h"
 #include "platform/OSXPasteboardPeeker.h"
-#include "synergy/Clipboard.h"
-#include "synergy/KeyMap.h"
-#include "synergy/ClientApp.h"
+#include "core/Clipboard.h"
+#include "core/KeyMap.h"
+#include "core/ClientApp.h"
 #include "mt/CondVar.h"
 #include "mt/Lock.h"
 #include "mt/Mutex.h"
 #include "mt/Thread.h"
 #include "arch/XArch.h"
-#include "base/Log.h"
+#include "base/EventQueue.h"
 #include "base/IEventQueue.h"
 #include "base/TMethodEventJob.h"
 #include "base/TMethodJob.h"
-#include "synergy/DisplayInvalidException.h"
+#include "base/Log.h"
 
 #include <math.h>
 #include <mach-o/dyld.h>
 #include <AvailabilityMacros.h>
 #include <IOKit/hidsystem/event_status_driver.h>
 #include <AppKit/NSEvent.h>
+#include <IOKit/hidsystem/IOHIDLib.h>
 
 // This isn't in any Apple SDK that I know of as of yet.
 enum {
@@ -106,12 +107,9 @@ OSXScreen::OSXScreen(IEventQueue* events, bool isPrimary, bool autoShowHideCurso
 	m_getDropTargetThread(NULL),
 	m_impl(NULL)
 {
-    m_displayID = CGMainDisplayID();
-    if (!updateScreenShape(m_displayID, 0)) {
-        throw DisplayInvalidException ("failed to initialize screen shape");
-    }
-
 	try {
+		m_displayID   = CGMainDisplayID();
+		updateScreenShape(m_displayID, 0);
 		m_screensaver = new OSXScreenSaver(m_events, getEventTarget());
 		m_keyState	  = new OSXKeyState(m_events);
 		
@@ -185,6 +183,33 @@ OSXScreen::OSXScreen(IEventQueue* events, bool isPrimary, bool autoShowHideCurso
 
 	// install the platform event queue
 	m_events->adoptBuffer(new OSXEventQueueBuffer(m_events));
+
+    if (m_isPrimary) {
+        m_eventTapPort = CGEventTapCreate(kCGHIDEventTap, kCGHeadInsertEventTap, kCGEventTapOptionDefault,
+                                        kCGEventMaskForAllEvents,
+                                        handleCGInputEvent,
+                                        this);
+    }
+    else {
+        // there may be a better way to do this, but we register an event handler even if we're
+        // not on the primary display (acting as a client). This way, if a local event comes in
+        // (either keyboard or mouse), we can make sure to show the cursor if we've hidden it.
+        m_eventTapPort = CGEventTapCreate(kCGHIDEventTap, kCGHeadInsertEventTap, kCGEventTapOptionDefault,
+                                        kCGEventMaskForAllEvents,
+                                        handleCGInputEventSecondary,
+                                        this);
+    }
+
+    if (!m_eventTapPort) {
+        LOG((CLOG_ERR "failed to create quartz event tap"));
+    }
+
+    m_eventTapRLSR = CFMachPortCreateRunLoopSource(kCFAllocatorDefault, m_eventTapPort, 0);
+    if (!m_eventTapRLSR) {
+        LOG((CLOG_ERR "failed to create a CFRunLoopSourceRef for the quartz event tap"));
+    }
+
+    CFRunLoopAddSource(CFRunLoopGetCurrent(), m_eventTapRLSR, kCFRunLoopDefaultMode);
 }
 
 OSXScreen::~OSXScreen()
@@ -222,6 +247,12 @@ OSXScreen::~OSXScreen()
 	delete m_keyState;
 	delete m_screensaver;
 	
+    if (m_eventTapPort) {
+        CGEventTapEnable(m_eventTapPort, false);
+        CFRelease(m_eventTapPort);
+        m_eventTapPort = nullptr;
+    }
+
 #if defined(MAC_OS_X_VERSION_10_7)
 	delete m_carbonLoopMutex;
 	delete m_carbonLoopReady;
@@ -518,67 +549,15 @@ OSXScreen::fakeMouseButton(ButtonID id, bool press)
 	if (index >= NumButtonIDs) {
 		return;
 	}
-	
-	CGPoint pos;
-	if (!m_cursorPosValid) {
-		SInt32 x, y;
-		getCursorPos(x, y);
-	}
-	pos.x = m_xCursor;
-	pos.y = m_yCursor;
 
-	// variable used to detect mouse coordinate differences between
-	// old & new mouse clicks. Used in double click detection.
-	SInt32 xDiff = m_xCursor - m_lastSingleClickXCursor;
-	SInt32 yDiff = m_yCursor - m_lastSingleClickYCursor;
-	double diff = sqrt(xDiff * xDiff + yDiff * yDiff);
-	// max sqrt(x^2 + y^2) difference allowed to double click
-	// since we don't have double click distance in NX APIs
-	// we define our own defaults.
-	const double maxDiff = sqrt(2) + 0.0001;
-    
-    double clickTime = [NSEvent doubleClickInterval];
-    
-    // As long as the click is within the time window and distance window
-    // increase clickState (double click, triple click, etc)
-    // This will allow for higher than triple click but the quartz documenation
-    // does not specify that this should be limited to triple click
-    if (press) {
-        if ((ARCH->time() - m_lastClickTime) <= clickTime && diff <= maxDiff){
-            m_clickState++;
-        }
-        else {
-            m_clickState = 1;
-        }
-        
-        m_lastClickTime = ARCH->time();
-    }
-    
-    if (m_clickState == 1){
-        m_lastSingleClickXCursor = m_xCursor;
-        m_lastSingleClickYCursor = m_yCursor;
-    }
-    
-    EMouseButtonState state = press ? kMouseButtonDown : kMouseButtonUp;
-    
     LOG((CLOG_DEBUG1 "faking mouse button id: %d press: %s", index, press ? "pressed" : "released"));
     
-    MouseButtonEventMapType thisButtonMap = MouseButtonEventMap[index];
-    CGEventType type = thisButtonMap[state];
+    OSXIOHID hid;
+    hid.fakeMouseButton(index, press);
 
-    CGEventRef event = CGEventCreateMouseEvent(NULL, type, pos, static_cast<CGMouseButton>(index));
-    
-    CGEventSetIntegerValueField(event, kCGMouseEventClickState, m_clickState);
-    
-    // Fix for sticky keys
-    CGEventFlags modifiers = m_keyState->getModifierStateAsOSXFlags();
-    CGEventSetFlags(event, modifiers);
-    
+    EMouseButtonState state = press ? kMouseButtonDown : kMouseButtonUp;
     m_buttonState.set(index, state);
-    CGEventPost(kCGHIDEventTap, event);
-    
-    CFRelease(event);
-    
+
 	if (!press && (id == kButtonLeft)) {
 		if (m_fakeDraggingStarted) {
 			m_getDropTargetThread = new Thread(new TMethodJob<OSXScreen>(
@@ -755,44 +734,14 @@ OSXScreen::enable()
 							new TMethodEventJob<OSXScreen>(this,
 								&OSXScreen::handleClipboardCheck));
 
-	if (m_isPrimary) {
-		// FIXME -- start watching jump zones
-		
-		// kCGEventTapOptionDefault = 0x00000000 (Missing in 10.4, so specified literally)
-		m_eventTapPort = CGEventTapCreate(kCGHIDEventTap, kCGHeadInsertEventTap, kCGEventTapOptionDefault,
-										kCGEventMaskForAllEvents, 
-										handleCGInputEvent, 
-										this);
-	}
-	else {
-		// FIXME -- prevent system from entering power save mode
-
+    if (!m_isPrimary) {
 		if (m_autoShowHideCursor) {
 			hideCursor();
 		}
 
 		// warp the mouse to the cursor center
 		fakeMouseMove(m_xCenter, m_yCenter);
-
-                // there may be a better way to do this, but we register an event handler even if we're
-                // not on the primary display (acting as a client). This way, if a local event comes in
-                // (either keyboard or mouse), we can make sure to show the cursor if we've hidden it. 
-		m_eventTapPort = CGEventTapCreate(kCGHIDEventTap, kCGHeadInsertEventTap, kCGEventTapOptionDefault,
-										kCGEventMaskForAllEvents, 
-										handleCGInputEventSecondary, 
-										this);
 	}
-
-	if (!m_eventTapPort) {
-		LOG((CLOG_ERR "failed to create quartz event tap"));
-	}
-
-	m_eventTapRLSR = CFMachPortCreateRunLoopSource(kCFAllocatorDefault, m_eventTapPort, 0);
-	if (!m_eventTapRLSR) {
-		LOG((CLOG_ERR "failed to create a CFRunLoopSourceRef for the quartz event tap"));
-	}
-
-	CFRunLoopAddSource(CFRunLoopGetCurrent(), m_eventTapRLSR, kCFRunLoopDefaultMode);
 }
 
 void
@@ -1216,10 +1165,9 @@ OSXScreen::displayReconfigurationCallback(CGDirectDisplayID displayID, CGDisplay
 	LOG((CLOG_DEBUG1 "event: display was reconfigured: %x %x %x", flags, mask, flags & mask));
 
 	if (flags & mask) { /* Something actually did change */
+		
 		LOG((CLOG_DEBUG1 "event: screen changed shape; refreshing dimensions"));
-        if (!screen->updateScreenShape(displayID, flags)) {
-            LOG((CLOG_ERR "failed to update screen shape during display reconfiguration"));
-        }
+		screen->updateScreenShape(displayID, flags);
 	}
 }
 
@@ -1523,34 +1471,35 @@ OSXScreen::getKeyState() const
 	return m_keyState;
 }
 
-bool OSXScreen::updateScreenShape(const CGDirectDisplayID, const CGDisplayChangeSummaryFlags flags)
+void
+OSXScreen::updateScreenShape(const CGDirectDisplayID, const CGDisplayChangeSummaryFlags flags)
 {
-    return updateScreenShape();
+	updateScreenShape();
 }
 
-bool
+void
 OSXScreen::updateScreenShape()
 {
 	// get info for each display
 	CGDisplayCount displayCount = 0;
 
 	if (CGGetActiveDisplayList(0, NULL, &displayCount) != CGDisplayNoErr) {
-        return false;
+		return;
 	}
 	
 	if (displayCount == 0) {
-        return false;
+		return;
 	}
 
 	CGDirectDisplayID* displays = new CGDirectDisplayID[displayCount];
 	if (displays == NULL) {
-        return false;
+		return;
 	}
 
 	if (CGGetActiveDisplayList(displayCount,
 							displays, &displayCount) != CGDisplayNoErr) {
 		delete[] displays;
-        return false;
+		return;
 	}
 
 	// get smallest rect enclosing all display rects
@@ -1579,8 +1528,6 @@ OSXScreen::updateScreenShape()
 	LOG((CLOG_DEBUG "screen shape: center=%d,%d size=%dx%d on %u %s",
          m_x, m_y, m_w, m_h, displayCount,
          (displayCount == 1) ? "display" : "displays"));
-
-    return true;
 }
 
 #pragma mark - 
@@ -1900,21 +1847,20 @@ OSXScreen::handleCGInputEventSecondary(
 	CGEventRef event,
 	void* refcon)
 {
-	// this fix is really screwing with the correct show/hide behavior. it
-	// should be tested better before reintroducing.
-	return event;
+    static pid_t currentPid = getpid();
+    auto sourcePid = CGEventGetIntegerValueField(event, kCGEventSourceUnixProcessID);
 
-	OSXScreen* screen = (OSXScreen*)refcon;
-	if (screen->m_cursorHidden && type == kCGEventMouseMoved) {
+    if (currentPid != sourcePid) {
+        switch(type) {
+            case kCGEventLeftMouseDown:
+            case kCGEventRightMouseDown:
+            case kCGEventOtherMouseDown:
+            case kCGEventKeyDown:
+            case kCGEventFlagsChanged:
+                LOG((CLOG_INFO "local input detected"));
+        }
+    }
 
-		CGPoint pos = CGEventGetLocation(event);
-		if (pos.x != screen->m_xCenter || pos.y != screen->m_yCenter) {
-
-			LOG((CLOG_DEBUG "show cursor on secondary, type=%d pos=%d,%d",
-					type, pos.x, pos.y));
-			screen->showCursor();
-		}
-	}
 	return event;
 }
 
