@@ -30,7 +30,6 @@
 #include "base/Stopwatch.h"
 #include "common/stdvector.h"
 
-#include <algorithm>
 #include <cstdio>
 #include <cstring>
 #include <X11/Xatom.h>
@@ -71,6 +70,7 @@ XWindowsClipboard::XWindowsClipboard(Display* display,
         m_selection = XInternAtom(m_display, "CLIPBOARD", False);
         break;
 
+    case kClipboardSelection:
     default:
         m_selection = XA_PRIMARY;
         break;
@@ -79,13 +79,9 @@ XWindowsClipboard::XWindowsClipboard(Display* display,
     // add converters, most desired first
     m_converters.push_back(new XWindowsClipboardHTMLConverter(m_display,
                                 "text/html"));
-    m_converters.push_back(new XWindowsClipboardHTMLConverter(m_display,
-                                "application/x-moz-nativehtml"));
     m_converters.push_back(new XWindowsClipboardBMPConverter(m_display));
     m_converters.push_back(new XWindowsClipboardUTF8Converter(m_display,
                                 "text/plain;charset=UTF-8"));
-    m_converters.push_back(new XWindowsClipboardUTF8Converter(m_display,
-                                "text/plain;charset=utf-8"));
     m_converters.push_back(new XWindowsClipboardUTF8Converter(m_display,
                                 "UTF8_STRING"));
     m_converters.push_back(new XWindowsClipboardUCS2Converter(m_display,
@@ -128,10 +124,12 @@ XWindowsClipboard::addRequest(Window owner, Window requestor,
     if (owner == m_window) {
         LOG((CLOG_DEBUG1 "request for clipboard %d, target %s by 0x%08x (property=%s)", m_selection, XWindowsUtil::atomToString(m_display, target).c_str(), requestor, XWindowsUtil::atomToString(m_display, property).c_str()));
         if (wasOwnedAtTime(time)) {
-            if (target == m_atomMultiple && property != None) {
+            if (target == m_atomMultiple) {
                 // add a multiple request.  property may not be None
                 // according to ICCCM.
-                success = insertMultipleReply(requestor, time, property);
+                if (property != None) {
+                    success = insertMultipleReply(requestor, time, property);
+                }
             }
             else {
                 addSimpleRequest(requestor, target, time, property);
@@ -178,7 +176,7 @@ XWindowsClipboard::addSimpleRequest(Window requestor,
     }
     else {
         IXWindowsClipboardConverter* converter = getConverter(target);
-        if (converter != nullptr) {
+        if (converter != NULL) {
             IClipboard::EFormat clipboardFormat = converter->getFormat();
             if (m_added[clipboardFormat]) {
                 try {
@@ -188,7 +186,6 @@ XWindowsClipboard::addSimpleRequest(Window requestor,
                 }
                 catch (...) {
                     // ignore -- cannot convert
-                    LOG((CLOG_WARN "error while converting clipboard data"));
                 }
             }
         }
@@ -407,7 +404,7 @@ XWindowsClipboard::clearConverters()
 IXWindowsClipboardConverter*
 XWindowsClipboard::getConverter(Atom target, bool onlyIfNotAdded) const
 {
-    IXWindowsClipboardConverter* converter = nullptr;
+    IXWindowsClipboardConverter* converter = NULL;
     for (ConverterList::const_iterator index = m_converters.begin();
                                 index != m_converters.end(); ++index) {
         converter = *index;
@@ -415,15 +412,17 @@ XWindowsClipboard::getConverter(Atom target, bool onlyIfNotAdded) const
             break;
         }
     }
-    if (converter == nullptr) {
+    if (converter == NULL) {
         LOG((CLOG_DEBUG1 "  no converter for target %s", XWindowsUtil::atomToString(m_display, target).c_str()));
-        return nullptr;
+        return NULL;
     }
 
     // optionally skip already handled targets
-    if (onlyIfNotAdded && m_added[converter->getFormat()]) {
-        LOG((CLOG_DEBUG1 "  skipping handled format %d", converter->getFormat()));
-        return nullptr;
+    if (onlyIfNotAdded) {
+        if (m_added[converter->getFormat()]) {
+            LOG((CLOG_DEBUG1 "  skipping handled format %d", converter->getFormat()));
+            return NULL;
+        }
     }
 
     return converter;
@@ -518,7 +517,7 @@ XWindowsClipboard::icccmFillCache()
     }
 
     XWindowsUtil::convertAtomProperty(data);
-    auto targets            = static_cast<const Atom*>(static_cast<const void*>(data.data()));
+    const Atom* targets = reinterpret_cast<const Atom*>(data.data()); // TODO: Safe?
     const UInt32 numTargets = data.size() / sizeof(Atom);
     LOG((CLOG_DEBUG "  available targets: %s", XWindowsUtil::atomsToString(m_display, targets, numTargets).c_str()));
 
@@ -571,8 +570,8 @@ bool
 XWindowsClipboard::icccmGetSelection(Atom target,
                 Atom* actualTarget, String* data) const
 {
-    assert(actualTarget != nullptr);
-    assert(data         != nullptr);
+    assert(actualTarget != NULL);
+    assert(data         != NULL);
 
     // request data conversion
     CICCCMGetClipboard getter(m_window, m_time, m_atomData);
@@ -596,7 +595,7 @@ XWindowsClipboard::icccmGetTime() const
     String data;
     if (icccmGetSelection(m_atomTimestamp, &actualTarget, &data) &&
         actualTarget == m_atomInteger) {
-        Time time = *static_cast<const Time*>(static_cast<const void*>(data.data()));
+        Time time = *reinterpret_cast<const Time*>(data.data());
         LOG((CLOG_DEBUG1 "got ICCCM time %d", time));
         return time;
     }
@@ -711,9 +710,8 @@ XWindowsClipboard::motifFillCache()
     }
 
     // get the Motif item property from the root window
-    static const int buffer_size = 18 + 20;
-    char name[buffer_size];
-    snprintf(name, buffer_size, "_MOTIF_CLIP_ITEM_%d", header.m_item);
+    char name[18 + 20];
+    sprintf(name, "_MOTIF_CLIP_ITEM_%d", header.m_item);
     Atom atomItem = XInternAtom(m_display, name, False);
     data = "";
     if (!XWindowsUtil::getWindowProperty(m_display, root,
@@ -734,14 +732,15 @@ XWindowsClipboard::motifFillCache()
 
     // format list is after static item structure elements
     const SInt32 numFormats = item.m_numFormats - item.m_numDeletedFormats;
-    auto formats            = static_cast<const SInt32*>(static_cast<const void*>(item.m_size + data.data()));
+    const SInt32* formats   = reinterpret_cast<const SInt32*>(item.m_size +
+                                static_cast<const char*>(data.data()));
 
     // get the available formats
     typedef std::map<Atom, String> MotifFormatMap;
     MotifFormatMap motifFormats;
     for (SInt32 i = 0; i < numFormats; ++i) {
         // get Motif format property from the root window
-        snprintf(name, buffer_size, "_MOTIF_CLIP_ITEM_%d", formats[i]);
+        sprintf(name, "_MOTIF_CLIP_ITEM_%d", formats[i]);
         Atom atomFormat = XInternAtom(m_display, name, False);
         String data;
         if (!XWindowsUtil::getWindowProperty(m_display, root,
@@ -823,14 +822,13 @@ XWindowsClipboard::motifGetSelection(const MotifClipFormat* format,
     // already stored on the root window and only if it fits in a
     // property.  motif has some scheme for transferring part by
     // part that i don't know.
-    static const int buffer_size = 18+20;
-    char name[buffer_size];
-    snprintf(name, buffer_size, "_MOTIF_CLIP_ITEM_%d", format->m_data);
+    char name[18 + 20];
+    sprintf(name, "_MOTIF_CLIP_ITEM_%d", format->m_data);
        Atom target = XInternAtom(m_display, name, False);
     Window root = RootWindow(m_display, DefaultScreen(m_display));
     return XWindowsUtil::getWindowProperty(m_display, root,
                                 target, data,
-                                actualTarget, nullptr, False);
+                                actualTarget, NULL, False);
 }
 
 IClipboard::Time
@@ -860,7 +858,7 @@ XWindowsClipboard::insertMultipleReply(Window requestor,
 
     // data is a list of atom pairs:  target, property
     XWindowsUtil::convertAtomProperty(data);
-    auto targets = static_cast<const Atom*>(static_cast<const void*>(data.data()));
+    const Atom* targets = reinterpret_cast<const Atom*>(data.data());
     const UInt32 numTargets = data.size() / sizeof(Atom);
 
     // add replies for each target
@@ -892,7 +890,7 @@ XWindowsClipboard::insertMultipleReply(Window requestor,
 void
 XWindowsClipboard::insertReply(Reply* reply)
 {
-    assert(reply != nullptr);
+    assert(reply != NULL);
 
     // note -- we must respond to requests in order if requestor,target,time
     // are the same, otherwise we can use whatever order we like with one
@@ -993,7 +991,7 @@ XWindowsClipboard::pushReplies(ReplyMap::iterator& mapIndex,
 bool
 XWindowsClipboard::sendReply(Reply* reply)
 {
-    assert(reply != nullptr);
+    assert(reply != NULL);
 
     // bail out immediately if reply is done
     if (reply->m_done) {
@@ -1081,76 +1079,67 @@ XWindowsClipboard::sendReply(Reply* reply)
         }
     }
 
-    // notification already sended
-    if (reply->m_replied) {
-        return false;
-        
-    }
+    // send notification if we haven't yet
+    if (!reply->m_replied) {
+        LOG((CLOG_DEBUG1 "clipboard: sending notify to 0x%08x,%d,%d", reply->m_requestor, reply->m_target, reply->m_property));
+        reply->m_replied = true;
 
-    LOG((CLOG_DEBUG1 "clipboard: sending notify to 0x%08x,%d,%d", reply->m_requestor, reply->m_target, reply->m_property));
-    reply->m_replied = true;
+        // dump every property on the requestor window to the debug2
+        // log.  we've seen what appears to be a bug in lesstif and
+        // knowing the properties may help design a workaround, if
+        // it becomes necessary.
+        if (CLOG->getFilter() >= kDEBUG2) {
+            XWindowsUtil::ErrorLock lock(m_display);
+            int n;
+            Atom* props = XListProperties(m_display, reply->m_requestor, &n);
+            LOG((CLOG_DEBUG2 "properties of 0x%08x:", reply->m_requestor));
+            for (int i = 0; i < n; ++i) {
+                Atom target;
+                String data;
+                char* name = XGetAtomName(m_display, props[i]);
+                if (!XWindowsUtil::getWindowProperty(m_display,
+                                reply->m_requestor,
+                                props[i], &data, &target, NULL, False)) {
+                    LOG((CLOG_DEBUG2 "  %s: <can't read property>", name));
+                }
+                else {
+                    // if there are any non-ascii characters in string
+                    // then print the binary data.
+                    static const char* hex = "0123456789abcdef";
+                    for (String::size_type j = 0; j < data.size(); ++j) {
+                        if (data[j] < 32 || data[j] > 126) {
+                            String tmp;
+                            tmp.reserve(data.size() * 3);
+                            for (j = 0; j < data.size(); ++j) {
+                                unsigned char v = (unsigned char)data[j];
+                                tmp += hex[v >> 16];
+                                tmp += hex[v & 15];
+                                tmp += ' ';
+                            }
+                            data = tmp;
+                            break;
+                        }
+                    }
+                    char* type = XGetAtomName(m_display, target);
+                    LOG((CLOG_DEBUG2 "  %s (%s): %s", name, type, data.c_str()));
+                    if (type != NULL) {
+                        XFree(type);
+                    }
+                }
+                if (name != NULL) {
+                    XFree(name);
+                }
+            }
+            if (props != NULL) {
+                XFree(props);
+            }
+        }
 
-    // nothing to log
-    if (CLOG->getFilter() < kDEBUG2) {
         sendNotify(reply->m_requestor, m_selection,
-                        reply->m_target, reply->m_property,
-                        static_cast<unsigned int>(reply->m_time));
-
-        // wait for delete notify
-        return false;
-        
+                                reply->m_target, reply->m_property,
+                                reply->m_time);
     }
 
-    // dump every property on the requestor window to the debug2
-    // log.  we've seen what appears to be a bug in lesstif and
-    // knowing the properties may help design a workaround, if
-    // it becomes necessary.
-    XWindowsUtil::ErrorLock lock(m_display);
-    int n;
-    Atom* props = XListProperties(m_display, reply->m_requestor, &n);
-    LOG((CLOG_DEBUG2 "properties of 0x%08x:", reply->m_requestor));
-    for (int i = 0; i < n; ++i) {
-        Atom target;
-        String data;
-        char* name = XGetAtomName(m_display, props[i]);
-        if (!XWindowsUtil::getWindowProperty(m_display,
-                        reply->m_requestor,
-                        props[i], &data, &target, nullptr, False)) {
-            LOG((CLOG_DEBUG2 "  %s: <can't read property>", name));
-        }
-        else {
-            // convert to hex if contains non ascii symbols
-            if (std::find_if(data.begin(), data.end(),
-                                    [](const unsigned char& c) { return c < 32 || c > 126; }) != data.end()) {
-                const String hex_digits = "0123456789abcdef";
-                String tmp;
-                tmp.reserve(data.length() * 3);
-                std::for_each(data.begin(), data.end(), [hex_digits, &tmp](const unsigned char& c)
-                    {
-                        tmp += hex_digits[c >> 16];
-                        tmp += hex_digits[c & 15];
-                        tmp += ' ';
-                    });
-                data = tmp;
-            }
-            char* type = XGetAtomName(m_display, target);
-            LOG((CLOG_DEBUG2 "  %s (%s): %s", name, type, data.c_str()));
-            if (type != nullptr) {
-                XFree(type);
-            }
-        }
-        if (name != nullptr) {
-            XFree(name);
-        }
-    }
-    if (props != nullptr) {
-        XFree(props);
-    }
-
-    sendNotify(reply->m_requestor, m_selection,
-                            reply->m_target, reply->m_property,
-                            reply->m_time);
-
     // wait for delete notify
     return false;
 }
@@ -1229,7 +1218,7 @@ XWindowsClipboard::wasOwnedAtTime(::Time time) const
 Atom
 XWindowsClipboard::getTargetsData(String& data, int* format) const
 {
-    assert(format != nullptr);
+    assert(format != NULL);
 
     // add standard targets
     XWindowsUtil::appendAtomData(data, m_atomTargets);
@@ -1254,7 +1243,7 @@ XWindowsClipboard::getTargetsData(String& data, int* format) const
 Atom
 XWindowsClipboard::getTimestampData(String& data, int* format) const
 {
-    assert(format != nullptr);
+    assert(format != NULL);
 
     checkCache();
     XWindowsUtil::appendTimeData(data, m_timeOwned);
@@ -1276,6 +1265,8 @@ XWindowsClipboard::CICCCMGetClipboard::CICCCMGetClipboard(
     m_failed(false),
     m_done(false),
     m_reading(false),
+    m_data(NULL),
+    m_actualTarget(NULL),
     m_error(false)
 {
     // do nothing
@@ -1290,8 +1281,8 @@ bool
 XWindowsClipboard::CICCCMGetClipboard::readClipboard(Display* display,
                 Atom selection, Atom target, Atom* actualTarget, String* data)
 {
-    assert(actualTarget != nullptr);
-    assert(data         != nullptr);
+    assert(actualTarget != NULL);
+    assert(data         != NULL);
 
     LOG((CLOG_DEBUG1 "request selection=%s, target=%s, window=%x", XWindowsUtil::atomToString(display, selection).c_str(), XWindowsUtil::atomToString(display, target).c_str(), m_requestor));
 
@@ -1342,12 +1333,6 @@ XWindowsClipboard::CICCCMGetClipboard::readClipboard(Display* display,
         // process events if any otherwise sleep
         if (noWait || XPending(display) > 0) {
             while (!m_done && !m_failed && (noWait || XPending(display) > 0)) {
-                // fail if timeout has expired
-                if (timeout.getTime() >= s_timeout) {
-                    m_failed = true;
-                    break;
-                }
-
                 XNextEvent(display, &xevent);
                 if (!processEvent(display, &xevent)) {
                     // not processed so save it
@@ -1441,7 +1426,7 @@ XWindowsClipboard::CICCCMGetClipboard::processEvent(
     Atom target;
     const String::size_type oldSize = m_data->size();
     if (!XWindowsUtil::getWindowProperty(display, m_requestor,
-                                m_property, m_data, &target, nullptr, True)) {
+                                m_property, m_data, &target, NULL, True)) {
         // unable to read property
         m_failed = true;
         return true;
@@ -1451,7 +1436,11 @@ XWindowsClipboard::CICCCMGetClipboard::processEvent(
     // selection owner is busted.  if the INCR property has no size
     // then the selection owner is busted.
     if (target == m_atomIncr) {
-        if (m_incr || m_data->size() == oldSize) {
+        if (m_incr) {
+            m_failed = true;
+            m_error  = true;
+        }
+        else if (m_data->size() == oldSize) {
             m_failed = true;
             m_error  = true;
         }
