@@ -2,11 +2,11 @@
  * synergy -- mouse and keyboard sharing utility
  * Copyright (C) 2012-2016 Symless Ltd.
  * Copyright (C) 2002 Chris Schoeneman
- *
+ * 
  * This package is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
  * found in the file LICENSE that should have accompanied this file.
- *
+ * 
  * This package is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -23,11 +23,9 @@
 #include "platform/XWindowsKeyState.h"
 #include "platform/XWindowsScreenSaver.h"
 #include "platform/XWindowsUtil.h"
-#include "synergy/Clipboard.h"
-#include "synergy/KeyMap.h"
-#include "synergy/XScreen.h"
-#include "synergy/ArgsBase.h"
-#include "synergy/App.h"
+#include "core/Clipboard.h"
+#include "core/KeyMap.h"
+#include "core/XScreen.h"
 #include "arch/XArch.h"
 #include "arch/Arch.h"
 #include "base/Log.h"
@@ -39,7 +37,6 @@
 #include <cstring>
 #include <cstdlib>
 #include <algorithm>
-#include <thread>
 #if X_DISPLAY_MISSING
 #	error X11 is required to build synergy
 #else
@@ -105,7 +102,7 @@ XWindowsScreen::XWindowsScreen(
 	m_display(NULL),
 	m_root(None),
 	m_window(None),
-	m_isOnScreen(m_isPrimary),
+	m_isOnScreen(true),
 	m_x(0), m_y(0),
 	m_w(0), m_h(0),
 	m_xCenter(0), m_yCenter(0),
@@ -131,11 +128,11 @@ XWindowsScreen::XWindowsScreen(
 
 	if (mouseScrollDelta==0) m_mouseScrollDelta=120;
 	s_screen = this;
-
+	
 	if (!disableXInitThreads) {
 	  // initializes Xlib support for concurrent threads.
 	  if (XInitThreads() == 0)
-		throw XArch("XInitThreads() returned zero");
+	    throw XArch("XInitThreads() returned zero");
 	} else {
 		LOG((CLOG_DEBUG "skipping XInitThreads()"));
 	}
@@ -162,7 +159,6 @@ XWindowsScreen::XWindowsScreen(
 	}
 
 	// primary/secondary screen only initialization
-	if (m_isPrimary) {
 #ifdef HAVE_XI2
 		m_xi2detected = detectXI2();
 		if (m_xi2detected) {
@@ -176,17 +172,11 @@ XWindowsScreen::XWindowsScreen(
 
 		// prepare to use input methods
 		openIM();
-	}
-	else {
+	if (!m_isPrimary) {
 		// become impervious to server grabs
 		XTestGrabControl(m_display, True);
 	}
 
-    // disable sleep if the flag is set
-    if (App::instance().argsBase().m_preventSleep) {
-        m_powerManager.disableSleep();
-    }
-
 	// initialize the clipboards
 	for (ClipboardID id = 0; id < kClipboardEnd; ++id) {
 		m_clipboard[id] = new XWindowsClipboard(m_display, m_window, id);
@@ -224,8 +214,7 @@ XWindowsScreen::~XWindowsScreen()
 		if (m_im != NULL) {
 			XCloseIM(m_im);
 		}
-		XDestroyWindow(m_display, m_window);
-		XCloseDisplay(m_display);
+		XDestroyWindow(m_display, m_window);		XCloseDisplay(m_display);
 	}
 	XSetIOErrorHandler(NULL);
 
@@ -250,7 +239,7 @@ XWindowsScreen::enable()
 		XMapRaised(m_display, m_window);
 
 		// warp the mouse to the cursor center
-		fakeMouseMove(m_xCenter, m_yCenter);
+		warpCursor(m_xCenter, m_yCenter);
 	}
 }
 
@@ -296,21 +285,21 @@ XWindowsScreen::enter()
 	CARD16 powerlevel;
 	BOOL enabled;
 	if (DPMSQueryExtension(m_display, &dummy, &dummy) &&
-		DPMSCapable(m_display) &&
-		DPMSInfo(m_display, &powerlevel, &enabled))
+	    DPMSCapable(m_display) &&
+	    DPMSInfo(m_display, &powerlevel, &enabled))
 	{
 		if (enabled && powerlevel != DPMSModeOn)
 			DPMSForceLevel(m_display, DPMSModeOn);
 	}
 	#endif
-
+	
 	// unmap the hider/grab window.  this also ungrabs the mouse and
 	// keyboard if they're grabbed.
 	XUnmapWindow(m_display, m_window);
 
 /* maybe call this if entering for the screensaver
 	// set keyboard focus to root window.  the screensaver should then
-	// pick up key events for when the user enters a password to unlock.
+	// pick up key events for when the user enters a password to unlock. 
 	XSetInputFocus(m_display, PointerRoot, PointerRoot, CurrentTime);
 */
 
@@ -352,7 +341,7 @@ XWindowsScreen::leave()
 	XMapRaised(m_display, m_window);
 
 	// grab the mouse and keyboard, if primary and possible
-	if (m_isPrimary && !grabMouseAndKeyboard()) {
+	if (!grabMouseAndKeyboard()) {
 		XUnmapWindow(m_display, m_window);
 		return false;
 	}
@@ -361,19 +350,14 @@ XWindowsScreen::leave()
 	XGetInputFocus(m_display, &m_lastFocus, &m_lastFocusRevert);
 
 	// take focus
-	if (m_isPrimary || !m_preserveFocus) {
+	if (!m_preserveFocus) {
 		XSetInputFocus(m_display, m_window, RevertToPointerRoot, CurrentTime);
 	}
 
 	// now warp the mouse.  we warp after showing the window so we're
 	// guaranteed to get the mouse leave event and to prevent the
 	// keyboard focus from changing under point-to-focus policies.
-	if (m_isPrimary) {
-		warpCursor(m_xCenter, m_yCenter);
-	}
-	else {
-		fakeMouseMove(m_xCenter, m_yCenter);
-	}
+	warpCursor(m_xCenter, m_yCenter);
 
 	// set input context focus to our window
 	if (m_ic != NULL) {
@@ -483,13 +467,6 @@ XWindowsScreen::isPrimary() const
 	return m_isPrimary;
 }
 
-String
-XWindowsScreen::getSecureInputApp() const
-{
-	// ignore on Linux
-	return "";
-}
-
 void*
 XWindowsScreen::getEventTarget() const
 {
@@ -851,7 +828,7 @@ XWindowsScreen::fakeMouseMove(SInt32 x, SInt32 y)
 {
 	if (m_xinerama && m_xtestIsXineramaUnaware) {
 		XWarpPointer(m_display, None, m_root, 0, 0, 0, 0, x, y);
-	}
+	} 
 	else {
 		XTestFakeMotionEvent(m_display, DefaultScreen(m_display),
 							x, y, CurrentTime);
@@ -863,7 +840,12 @@ void
 XWindowsScreen::fakeMouseRelativeMove(SInt32 dx, SInt32 dy) const
 {
 	// FIXME -- ignore xinerama for now
-	XTestFakeRelativeMotionEvent(m_display, dx, dy, CurrentTime);
+	if (false && m_xinerama && m_xtestIsXineramaUnaware) {
+//		XWarpPointer(m_display, None, m_root, 0, 0, 0, 0, x, y);
+	}
+	else {
+		XTestFakeRelativeMotionEvent(m_display, dx, dy, CurrentTime);
+	}
 	XFlush(m_display);
 }
 
@@ -875,12 +857,6 @@ XWindowsScreen::fakeMouseWheel(SInt32, SInt32 yDelta) const
 		return;
 	}
 
-	// use mouse scroll direction for inversion
-	if( m_scrollDirectionMouse < 0 )
-	{
-		yDelta = -yDelta;
-	}
-
 	// choose button depending on rotation direction
 	const unsigned int xButton = mapButtonToX(static_cast<ButtonID>(
 												(yDelta >= 0) ? -1 : -2));
@@ -1027,53 +1003,6 @@ XWindowsScreen::saveShape()
 #endif
 }
 
-void
-XWindowsScreen::setShape(SInt32 width, SInt32 height)
-{
-	// set shape
-	m_x = 0;
-	m_y = 0;
-
-	m_w = width;
-	m_h = height;
-
-	// get center of default screen
-	m_xCenter = m_x + (m_w >> 1);
-	m_yCenter = m_y + (m_h >> 1);
-
-	// check if xinerama is enabled and there is more than one screen.
-	// get center of first Xinerama screen.  Xinerama appears to have
-	// a bug when XWarpPointer() is used in combination with
-	// XGrabPointer().  in that case, the warp is successful but the
-	// next pointer motion warps the pointer again, apparently to
-	// constrain it to some unknown region, possibly the region from
-	// 0,0 to Wm,Hm where Wm (Hm) is the minimum width (height) over
-	// all physical screens.  this warp only seems to happen if the
-	// pointer wasn't in that region before the XWarpPointer().  the
-	// second (unexpected) warp causes synergy to think the pointer
-	// has been moved when it hasn't.  to work around the problem,
-	// we warp the pointer to the center of the first physical
-	// screen instead of the logical screen.
-	m_xinerama = false;
-#if HAVE_X11_EXTENSIONS_XINERAMA_H
-	int eventBase, errorBase;
-	if ((XineramaQueryExtension(m_display, &eventBase, &errorBase) != 0) &&
-		(XineramaIsActive(m_display) != 0)) {
-		int numScreens;
-		XineramaScreenInfo* screens;
-		screens = XineramaQueryScreens(m_display, &numScreens);
-		if (screens != nullptr) {
-			if (numScreens > 1) {
-				m_xinerama = true;
-				m_xCenter  = screens[0].x_org + (screens[0].width  >> 1);
-				m_yCenter  = screens[0].y_org + (screens[0].height >> 1);
-			}
-			XFree(screens);
-		}
-	}
-#endif
-}
-
 Window
 XWindowsScreen::openWindow() const
 {
@@ -1107,7 +1036,10 @@ XWindowsScreen::openWindow() const
 		// moved.  we'll reposition the window as necessary so its
 		// position here doesn't matter.  it only needs to be 1x1 because
 		// it only needs to contain the cursor's hotspot.
-		attr.event_mask = LeaveWindowMask;
+		attr.event_mask = PointerMotionMask |
+							 ButtonPressMask | ButtonReleaseMask |
+							 KeyPressMask | KeyReleaseMask |
+							 KeymapStateMask;
 		x = 0;
 		y = 0;
 		w = 1;
@@ -1187,9 +1119,6 @@ XWindowsScreen::openIM()
 	XWindowAttributes attr;
 	XGetWindowAttributes(m_display, m_window, &attr);
 	XSelectInput(m_display, m_window, attr.your_event_mask | mask);
-
-	// listen for screen-resize messages
-	XSelectInput (m_display, m_root, StructureNotifyMask);
 }
 
 void
@@ -1319,27 +1248,31 @@ XWindowsScreen::handleSystemEvent(const Event& event, void*)
 				cookie->type == GenericEvent &&
 				cookie->extension == xi_opcode) {
 			if (cookie->evtype == XI_RawMotion) {
-				// Get current pointer's position
-				Window root, child;
-				XMotionEvent xmotion;
-				xmotion.type = MotionNotify;
-				xmotion.send_event = False; // Raw motion
-				xmotion.display = m_display;
-				xmotion.window = m_window;
-				/* xmotion's time, state and is_hint are not used */
-				unsigned int msk;
-					xmotion.same_screen = XQueryPointer(
-						m_display, m_root, &xmotion.root, &xmotion.subwindow,
-						&xmotion.x_root,
-						&xmotion.y_root,
-						&xmotion.x,
-						&xmotion.y,
-						&msk);
+				if (m_isPrimary) {
+					// Get current pointer's position
+					Window root, child;
+					XMotionEvent xmotion;
+					xmotion.type = MotionNotify;
+					xmotion.send_event = False; // Raw motion
+					xmotion.display = m_display;
+					xmotion.window = m_window;
+					/* xmotion's time, state and is_hint are not used */
+					unsigned int msk;
+						xmotion.same_screen = XQueryPointer(
+							m_display, m_root, &xmotion.root, &xmotion.subwindow,
+							&xmotion.x_root,
+							&xmotion.y_root,
+							&xmotion.x,
+							&xmotion.y,
+							&msk);
 					onMouseMove(xmotion);
-					XFreeEventData(m_display, cookie);
-					return;
-			}
+				} else if (!m_isOnScreen) {
+					LOG ((CLOG_INFO "local input detected"));
+				}
 				XFreeEventData(m_display, cookie);
+				return;
+			}
+			XFreeEventData(m_display, cookie);
 		}
 	}
 #endif
@@ -1425,37 +1358,40 @@ XWindowsScreen::handleSystemEvent(const Event& event, void*)
 	case KeyPress:
 		if (m_isPrimary) {
 			onKeyPress(xevent->xkey);
+		} else {
+			LOG ((CLOG_INFO "local input detected"));
 		}
 		return;
 
 	case KeyRelease:
 		if (m_isPrimary) {
 			onKeyRelease(xevent->xkey, isRepeat);
+		} else {
+			LOG ((CLOG_INFO "local input detected"));
 		}
 		return;
 
 	case ButtonPress:
 		if (m_isPrimary) {
 			onMousePress(xevent->xbutton);
+		} else {
+			LOG ((CLOG_INFO "local input detected"));
 		}
 		return;
 
 	case ButtonRelease:
 		if (m_isPrimary) {
 			onMouseRelease(xevent->xbutton);
+		} else {
+			LOG ((CLOG_INFO "local input detected"));
 		}
 		return;
 
 	case MotionNotify:
 		if (m_isPrimary) {
 			onMouseMove(xevent->xmotion);
-		}
-		return;
-
-	case ConfigureNotify:
-		if (!m_isPrimary && xevent->xconfigure.window == m_root) {
-			setShape(xevent->xconfigure.width, xevent->xconfigure.height);
-			sendEvent(m_events->forIScreen().shapeChanged());
+		} else if (!m_isOnScreen && (xevent->xmotion.send_event == False)) {
+			LOG ((CLOG_INFO "local input detected"));
 		}
 		return;
 
@@ -1546,9 +1482,9 @@ XWindowsScreen::onKeyPress(XKeyEvent& xkey)
 							false, false, key, mask, 1, keycode);
 		}
 	}
-	else {
+    else {
 		LOG((CLOG_DEBUG1 "can't map keycode to key id"));
-	}
+    }
 }
 
 void
@@ -1638,13 +1574,11 @@ XWindowsScreen::onMouseRelease(const XButtonEvent& xbutton)
 	}
 	else if (xbutton.button == 4) {
 		// wheel forward (away from user)
-		// invert for natural scroll setting
-		sendEvent(m_events->forIPrimaryScreen().wheel(), WheelInfo::alloc(0, 120 * m_scrollDirectionMouse));
+		sendEvent(m_events->forIPrimaryScreen().wheel(), WheelInfo::alloc(0, 120));
 	}
 	else if (xbutton.button == 5) {
 		// wheel backward (toward user)
-		// invert for natural scroll setting
-		sendEvent(m_events->forIPrimaryScreen().wheel(), WheelInfo::alloc(0, -120 * m_scrollDirectionMouse));
+		sendEvent(m_events->forIPrimaryScreen().wheel(), WheelInfo::alloc(0, -120));
 	}
 	// XXX -- support x-axis scrolling
 }
@@ -1871,7 +1805,7 @@ XWindowsScreen::doSelectEvents(Window w) const
 	// select events of interest.  do this before querying the tree so
 	// we'll get notifications of children created after the XQueryTree()
 	// so we won't miss them.
-	   XSelectInput(m_display, w, mask);
+       XSelectInput(m_display, w, mask);
 
 	// recurse on child windows
 	Window rw, pw, *cw;
@@ -2163,34 +2097,9 @@ XWindowsScreen::selectXIRawMotion()
 	mask.mask = (unsigned char*)calloc(mask.mask_len, sizeof(char));
 	mask.deviceid = XIAllMasterDevices;
 	memset(mask.mask, 0, 2);
-	XISetMask(mask.mask, XI_RawKeyRelease);
+    XISetMask(mask.mask, XI_RawKeyRelease);
 	XISetMask(mask.mask, XI_RawMotion);
 	XISelectEvents(m_display, DefaultRootWindow(m_display), &mask, 1);
 	free(mask.mask);
 }
 #endif
-
-void
-XWindowsScreen::updateScrollDirection()
-{
-	if (m_shouldUpdateScrollDirection)
-	{
-		m_shouldUpdateScrollDirection = false;
-
-		std::thread scrollDirectionUpdateThread([this]{
-			std::string mouseScroll = ArchSystemUnix::runCommand("gsettings get org.gnome.desktop.peripherals.mouse natural-scroll");
-			if(mouseScroll == "false\n")
-				m_scrollDirectionMouse = 1;
-			else if(mouseScroll == "true\n")
-				m_scrollDirectionMouse = -1;
-
-			std::string touchpadScroll = ArchSystemUnix::runCommand("gsettings get org.gnome.desktop.peripherals.touchpad natural-scroll");
-			if(touchpadScroll == "false\n")
-				m_scrollDirectionTouchpad = 1;
-			else if(touchpadScroll == "true\n")
-				m_scrollDirectionTouchpad = -1;
-		});
-		scrollDirectionUpdateThread.detach();
-	}
-}
-
