@@ -18,7 +18,7 @@
 
 #include "platform/XWindowsUtil.h"
 
-#include "synergy/key_types.h"
+#include "core/key_types.h"
 #include "mt/Thread.h"
 #include "base/Log.h"
 #include "base/String.h"
@@ -1781,10 +1781,8 @@ XWindowsUtil::ErrorLock::ignoreHandler(Display*, XErrorEvent* e, void*)
 }
 
 void
-XWindowsUtil::ErrorLock::saveHandler(Display* display, XErrorEvent* e, void* flag)
+XWindowsUtil::ErrorLock::saveHandler(Display*, XErrorEvent* e, void* flag)
 {
-    char errtxt[1024];
-    XGetErrorText(display, e->error_code, errtxt, 1023);
-    LOG((CLOG_DEBUG1 "flagging X error: %d - %.1023s", e->error_code, errtxt));
+    LOG((CLOG_DEBUG1 "flagging X error: %d", e->error_code));
     *static_cast<bool*>(flag) = true;
 }
