@@ -19,8 +19,8 @@
 #include "server/Config.h"
 
 #include "server/Server.h"
-#include "synergy/KeyMap.h"
-#include "synergy/key_types.h"
+#include "core/KeyMap.h"
+#include "core/key_types.h"
 #include "net/XSocket.h"
 #include "base/IEventQueue.h"
 #include "common/stdistream.h"
@@ -137,9 +137,9 @@ Config::removeScreen(const String& name)
 			m_nameToCanonicalName.erase(iter++);
 		}
 		else {
-            ++iter;
+			++index;
 		}
-    }
+	}
 }
 
 void
@@ -577,30 +577,28 @@ Config::operator==(const Config& x) const
 		return false;
 	}
 
-	auto index2map = x.m_map.cbegin();
-	for (auto const &index1: m_map) {
+	for (CellMap::const_iterator index1 = m_map.begin(),
+								index2 = x.m_map.begin();
+								index1 != m_map.end(); ++index1, ++index2) {
 		// compare names
-		if (!CaselessCmp::equal(index1.first, index2map->first)) {
+		if (!CaselessCmp::equal(index1->first, index2->first)) {
 			return false;
 		}
 
 		// compare cells
-		if (index1.second != index2map->second) {
+		if (index1->second != index2->second) {
 			return false;
 		}
-		++index2map;
 	}
 
-	auto index2 = x.m_nameToCanonicalName.cbegin();
-	for (auto const &index1: m_nameToCanonicalName) {
-		if (index2 == x.m_nameToCanonicalName.cend()) {
-			return false; // second source ended
-		}
-		if (!CaselessCmp::equal(index1.first,  index2->first) ||
-			!CaselessCmp::equal(index1.second, index2->second)) {
+	for (NameMap::const_iterator index1 = m_nameToCanonicalName.begin(),
+								index2 = x.m_nameToCanonicalName.begin();
+								index1 != m_nameToCanonicalName.end();
+								++index1, ++index2) {
+		if (!CaselessCmp::equal(index1->first,  index2->first) ||
+			!CaselessCmp::equal(index1->second, index2->second)) {
 			return false;
 		}
-		++index2;
 	}
 
 	// compare input filters
@@ -758,21 +756,19 @@ Config::readSectionOptions(ConfigReadContext& s)
 		else if (name == "switchNeedsAlt") {
 			addOption("", kOptionScreenSwitchNeedsAlt, s.parseBoolean(value));
 		}
+		else if (name == "screenSaverSync") {
+			addOption("", kOptionScreenSaverSync, s.parseBoolean(value));
+		}
 		else if (name == "relativeMouseMoves") {
 			addOption("", kOptionRelativeMouseMoves, s.parseBoolean(value));
 		}
 		else if (name == "win32KeepForeground") {
 			addOption("", kOptionWin32KeepForeground, s.parseBoolean(value));
 		}
-		else if (name == "disableLockToScreen") {
-			addOption("", kOptionDisableLockToScreen, s.parseBoolean(value));
-		}
 		else if (name == "clipboardSharing") {
 			addOption("", kOptionClipboardSharing, s.parseBoolean(value));
 		}
-		else if (name == "clipboardSharingSize") {
-			addOption("", kOptionClipboardSharingSize, s.parseInt(value));
-		}
+
 		else {
 			handled = false;
 		}
@@ -1240,26 +1236,6 @@ Config::parseAction(ConfigReadContext& s,
 		action = new InputFilter::LockCursorToScreenAction(m_events, mode);
 	}
 
-    else if (name == "restartServer") {
-        if (args.size() > 1) {
-            throw XConfigRead(s, "syntax for action: restartServer([{{restart}}])");
-        }
-
-        InputFilter::RestartServer::Mode mode =
-                InputFilter::RestartServer::restart;
-
-        if (args.size() == 1) {
-            if (args[0] == "restart") {
-                mode = InputFilter::RestartServer::restart;
-            }
-            else {
-                throw XConfigRead(s, "syntax for action: restartServer([{restart}])");
-            }
-        }
-
-        action = new InputFilter::RestartServer(m_events, mode);
-    }
-
 	else if (name == "keyboardBroadcast") {
 		if (args.size() > 2) {
 			throw XConfigRead(s, "syntax for action: keyboardBroadcast([{off|on|toggle}[,screens]])");
@@ -1389,6 +1365,9 @@ Config::getOptionName(OptionID id)
 	if (id == kOptionScreenSwitchNeedsAlt) {
 		return "switchNeedsAlt";
 	}
+	if (id == kOptionScreenSaverSync) {
+		return "screenSaverSync";
+	}
 	if (id == kOptionXTestXineramaUnaware) {
 		return "xtestIsXineramaUnaware";
 	}
@@ -1401,15 +1380,9 @@ Config::getOptionName(OptionID id)
 	if (id == kOptionScreenPreserveFocus) {
 		return "preserveFocus";
 	}
-	if (id == kOptionDisableLockToScreen) {
-		return "disableLockToScreen";
-	}
 	if (id == kOptionClipboardSharing) {
 		return "clipboardSharing";
 	}
-	if (id == kOptionClipboardSharingSize) {
-		return "clipboardSharingSize";
-	}
 	return NULL;
 }
 
@@ -1422,12 +1395,12 @@ Config::getOptionValue(OptionID id, OptionValue value)
 		id == kOptionScreenSwitchNeedsShift ||
 		id == kOptionScreenSwitchNeedsControl ||
 		id == kOptionScreenSwitchNeedsAlt ||
+		id == kOptionScreenSaverSync ||
 		id == kOptionXTestXineramaUnaware ||
 		id == kOptionRelativeMouseMoves ||
 		id == kOptionWin32KeepForeground ||
 		id == kOptionScreenPreserveFocus ||
-		id == kOptionClipboardSharing ||
-		id == kOptionClipboardSharingSize) {
+		id == kOptionClipboardSharing) {
 		return (value != 0) ? "true" : "false";
 	}
 	if (id == kOptionModifierMapForShift ||
@@ -1750,25 +1723,24 @@ Config::Cell::operator==(const Cell& x) const
 	if (m_neighbors.size() != x.m_neighbors.size()) {
 		return false;
 	}
-
-	auto index2neighbors = x.m_neighbors.cbegin();
-	for (auto const &index1: m_neighbors) {
-		if (index1.first != index2neighbors->first) {
+	for (EdgeLinks::const_iterator index1 = m_neighbors.begin(),
+								index2 = x.m_neighbors.begin();
+								index1 != m_neighbors.end();
+								++index1, ++index2) {
+		if (index1->first != index2->first) {
 			return false;
 		}
-		if (index1.second != index2neighbors->second) {
+		if (index1->second != index2->second) {
 			return false;
 		}
 
 		// operator== doesn't compare names.  only compare destination
 		// names.
-		if (!CaselessCmp::equal(index1.second.getName(),
-								index2neighbors->second.getName())) {
+		if (!CaselessCmp::equal(index1->second.getName(),
+								index2->second.getName())) {
 			return false;
 		}
-		++index2neighbors;
 	}
-
 	return true;
 }
 
@@ -2139,9 +2111,7 @@ ConfigReadContext::parseInterval(const ArgList& args) const
 		throw XConfigRead(*this, "invalid interval \"%{1}\"", concatArgs(args));
 	}
 
-	float startInterval = static_cast<float>(startValue / 100.0f);
-	float endInterval = static_cast<float>(endValue / 100.0f);
-	return Config::Interval(startInterval, endInterval);
+	return Config::Interval(startValue / 100.0f, endValue / 100.0f);
 }
 
 void
