@@ -19,9 +19,9 @@
 #pragma once
 
 #include "server/InputFilter.h"
-#include "synergy/option_types.h"
-#include "synergy/protocol_types.h"
-#include "synergy/IPlatformScreen.h"
+#include "core/option_types.h"
+#include "core/protocol_types.h"
+#include "core/IPlatformScreen.h"
 #include "net/NetworkAddress.h"
 #include "base/String.h"
 #include "base/XBase.h"
@@ -151,8 +151,6 @@ public:
     public:
         explicit const_iterator() : m_i() { }
         explicit const_iterator(const internal_const_iterator& i) : m_i(i) { }
-        const_iterator(const const_iterator &src) =default;
-        ~const_iterator() =default;
 
         const_iterator&    operator=(const const_iterator& i) {
             m_i = i.m_i;
