@@ -19,7 +19,7 @@
 #include "server/InputFilter.h"
 #include "server/Server.h"
 #include "server/PrimaryClient.h"
-#include "synergy/KeyMap.h"
+#include "core/KeyMap.h"
 #include "base/EventQueue.h"
 #include "base/Log.h"
 #include "base/TMethodEventJob.h"
@@ -323,40 +323,6 @@ InputFilter::LockCursorToScreenAction::perform(const Event& event)
                                 Event::kDeliverImmediately));
 }
 
-
-InputFilter::RestartServer::RestartServer(
-        IEventQueue* events, Mode mode) :
-        m_mode(mode),
-        m_events(events)
-{
-    // do nothing
-}
-
-InputFilter::RestartServer::Mode
-InputFilter::RestartServer::getMode() const
-{
-    return m_mode;
-}
-
-InputFilter::Action *InputFilter::RestartServer::clone() const {
-    return new RestartServer(*this);
-}
-
-String
-InputFilter::RestartServer::format() const
-{
-    static const char* s_mode[] = { "restart" };
-
-    return synergy::string::sprintf("restartServer(%s)", s_mode[m_mode]);
-}
-
-void
-InputFilter::RestartServer::perform(const Event& event)
-{
-    //HACK Super hack we should gracefully exit
-   exit(0);
-}
-
 InputFilter::SwitchToScreenAction::SwitchToScreenAction(
         IEventQueue* events, const String& screen) :
     m_screen(screen),
@@ -497,7 +463,7 @@ InputFilter::KeyboardBroadcastAction::format() const
     }
     else {
         return synergy::string::sprintf("%s(%s,%.*s)", s_name, s_mode[m_mode],
-                            static_cast<int>(m_screens.size() >= 2 ? m_screens.size() - 2 : 0),
+                            m_screens.size() - 2,
                             m_screens.c_str() + 1);
     }
 }
@@ -578,7 +544,7 @@ InputFilter::KeystrokeAction::format() const
         return synergy::string::sprintf("%s(%s,%.*s)", type,
                             synergy::KeyMap::formatKey(m_keyInfo->m_key,
                                 m_keyInfo->m_mask).c_str(),
-                            strnlen(m_keyInfo->m_screens + 1, SIZE_MAX) - 1,
+                            strlen(m_keyInfo->m_screens + 1) - 1,
                             m_keyInfo->m_screens + 1);
     }
 }
@@ -1122,4 +1088,3 @@ InputFilter::handleEvent(const Event& event, void*)
     // not handled so pass through
     m_events->addEvent(myEvent);
 }
-
