@@ -22,17 +22,17 @@
 #include "server/ClientProxyUnknown.h"
 #include "server/PrimaryClient.h"
 #include "server/ClientListener.h"
-#include "synergy/FileChunk.h"
-#include "synergy/IPlatformScreen.h"
-#include "synergy/DropHelper.h"
-#include "synergy/option_types.h"
-#include "synergy/protocol_types.h"
-#include "synergy/XScreen.h"
-#include "synergy/XSynergy.h"
-#include "synergy/StreamChunker.h"
-#include "synergy/KeyState.h"
-#include "synergy/Screen.h"
-#include "synergy/PacketStreamFilter.h"
+#include "core/FileChunk.h"
+#include "core/IPlatformScreen.h"
+#include "core/DropHelper.h"
+#include "core/option_types.h"
+#include "core/protocol_types.h"
+#include "core/XScreen.h"
+#include "core/XSynergy.h"
+#include "core/StreamChunker.h"
+#include "core/KeyState.h"
+#include "core/Screen.h"
+#include "core/PacketStreamFilter.h"
 #include "net/TCPSocket.h"
 #include "net/IDataSocket.h"
 #include "net/IListenSocket.h"
