@@ -19,13 +19,13 @@
 #pragma once
 
 #include "server/Config.h"
-#include "synergy/clipboard_types.h"
-#include "synergy/Clipboard.h"
-#include "synergy/key_types.h"
-#include "synergy/mouse_types.h"
-#include "synergy/INode.h"
-#include "synergy/DragInformation.h"
-#include "synergy/ServerArgs.h"
+#include "core/clipboard_types.h"
+#include "core/Clipboard.h"
+#include "core/key_types.h"
+#include "core/mouse_types.h"
+#include "core/INode.h"
+#include "core/DragInformation.h"
+#include "core/ServerArgs.h"
 #include "base/Event.h"
 #include "base/Stopwatch.h"
 #include "base/EventTypes.h"
